/* © brix cross media AG, http://www.brix.ch - It is strictly forbidden to change, reuse or copy the source code of this document. */
;(function ( $, window, document, undefined ) {
    var pluginName = "anuraCollage",
        defaults = {
            server: 'https://celum.local/anura/first', // REQUIRED, which anura endpoint to use
            ext: '.do?', // extension of server pages (.php, .do)
            node: {kind: 101, id: 0}, // which node of what kind to show (101 = folder, 102 = collection, 103 = keyword)
            top: {number: 0, days: 0}, // show the top X downloads within the last Y days
            relations: {id: 0, version: null, type: null}, // show related assets of a particular asset
            assets: null, // load a defined list of assets from somewhere else
            search: {string: '', node: 0, keyword: 0},
            sort: null, // order: one of [id, name, uploaddate, lastmodified, extension, assettype], seq: asc or desc - i.e. {order: 'name', seq: 'asc'}
            locale: '', // ISO 639-1 code, blank for default
            target_height: 150, // desired height of a row
            partial_row: true, // allow the last row to be only partialy filled (may causes last row to be higher than expected)
            detail_view: 'anura', // one of: slimbox, colorbox, details, blank, none
            detail_settings: {}, // settings to pass to anura.details.js
            colorbox_min_height: 500, colorbox_settings: {}, // colorbox specific settings since detail_settings is used by anuraDetails
            alternative_name: { // alternative name (for slimbox etc.)
                id: 0, // information field ID
                always: false //always use the alternative name, not just for slimbox
            },
            basket: null, // object to use as a basket, initialized by a basket plugin
            state: '', // prefix for state in url (multi-instance) or false to disable state
            download_menu: true,
            download_directly: false, // make the different formats available directly
            force_zip: false, // force even single asset downloads to be delivered in a ZIP-file
            icon_transform: function(icon) {return icon.replace('/big/', '/small/')},
            send: false, // add a mailto-link (ID of the download format to use or true for the first)
            extended: false, // request extended asset properties (size, modified) etc. - has no effect other than that you could use them for sorting
            stream: false, // enables audio and video streaming - use with caution, might overload the server
            autoplay: true, // whether to automatically start playing (with vimeo and/or stream)
            paginate: false, // how many items to show per page, false to show all
            paginator: ['prev', 'next', 'pages', 'counter'],
            paginator_nav: {prev: '&larr;', next: '&rarr;'},
            limit: 0, // limit the results (or reported total) returned by the server
            caption: true, // show caption (name of the asset) on mouse over
            recursive: false, // load assets from all subnodes recursively (like keywords in 1.x)
            noderef: false, // show assets that have node referencing infofields to this node, 2.x
            infofields: [], // list of information field IDs to load with the list response (use sparingly)
            detail_trigger: true, // listen to the details=... parameter and show the assets details view (regardless of actual navigation context)
            lightbox_rel: 'lightbox-anura' // name of the rel attribute to use for lighbox triggers
        };
    function Plugin( element, options ) {
        this.element = this.container = $(element);
        if (!options.lightbox_rel && options.state) options.lightbox_rel = 'lightbox-anura-'+options.state;
        this.options = $.extend( {}, defaults, options );
        this.assets = [];
        this._defaults = defaults;
        this._name = pluginName;
        this.strings = null;
        this.download_formats = null;
        this.pageCall = {};
        this.init();
    }
    Plugin.prototype = {
        init: function() {
            var _this = this;
            if (!$.isEmptyObject(this.strings) && this.options.locale === this.strings_locale) {
                this.loadCollage();
            } else {
                $.anura.getJSON(this, this.options.server+'/asset'+_this.options.ext+'callback=?&string=anura.addToBasket' +
                    '&string=anura.removeFromBasket&string=anura.loadMore&string=MENUITEMID_MAILTO',
                    {locale: this.options.locale}, 'anuraCollageStrings', function (data) {
                        _this.strings = data;
                        _this.strings_locale = _this.options.locale;
                        _this.loadCollage();
                    });
            }
        },
        loadCollage: function() {
            var previous = this.element.find('.anura-collage-container'), _this = this;
            if (previous.length > 0) {
                this.container = previous.first();
            } else {
                this.container = $('<div />').addClass('anura-collage-container').appendTo(this.element);
            }
            this.container.removeClass('empty').empty().addClass('anura-loading')
                .removeClass(function (index, css) {return (css.match (/anura-locale-\S+/g) || []).join(' ');}).addClass('anura-locale-'+this.options.locale);

            if (this.options.download_directly && this.download_formats == null) this.requestDownloadFormats();

            this.pageCall = {url: this.options.server+'/node'+this.options.ext+'callback=?', name: 'anuraCollage',
                params: {locale: this.options.locale, alt_name: this.options.alternative_name.id, extended: this.options.extended}};
            if (this.options.sort) {
                if (typeof this.options.sort === "string") {
                    var s = this.options.sort.split('_'); this.options.sort = {};
                    this.options.sort.seq = s.pop();
                    this.options.sort.order = s.join('_'); // join again for info_123
                }
                $.extend(this.pageCall.params, {sort_order: this.options.sort.order, sort_order_seq: this.options.sort.seq || 'asc'});
            }
            if (this.options.limit > 0) this.pageCall.params.limit = this.options.limit;
            if (this.options.infofields.length > 0) $.extend(this.pageCall.params, {infofields: this.options.infofields.join(',')});

            if (this.options.assets) {
                return this.populateContainer(this.options.assets);
            } else if (this.options.search && (this.options.search.custom || this.options.search.string)) {
                this.pageCall.name = 'anuraCollageSearch';
                this.pageCall.url = this.options.server+'/node'+this.options.ext+'callback=?'+((this.options.search.custom)?('&'+this.options.search.custom):'');
                $.extend(this.pageCall.params, {search: this.options.search.string, search_node: this.options.search.node});
                this.options.search.string = '';
            } else if (this.options.node && this.options.node.id) {
                this.pageCall.name = 'anuraCollageNode';
                $.extend(this.pageCall.params, {kind: this.options.node.kind, id: this.options.node.id,
                    recursive: this.options.recursive, noderef: this.options.noderef});
            } else if (this.options.top && this.options.top.number) {
                this.pageCall.name = 'anuraCollageTopDl';
                $.extend(this.pageCall.params, {top: this.options.top.number, days: this.options.top.days});
            } else if (this.options.relations && this.options.relations.id) {
                this.pageCall.name = 'anuraCollageRel'+this.options.relations.id;
                $.extend(this.pageCall.params, {relations: this.options.relations.id});
                if (this.options.relations.version) $.extend(this.pageCall.params, {version: this.options.relations.version});
                if (this.options.relations.type) $.extend(this.pageCall.params, {type: this.options.relations.type});
            } else {
                this.container.addClass('empty').removeClass('anura-loading');
                return;
            }
            this.element.data('page-call', this.pageCall);

            this.showPage(0);

            if (this.options.detail_trigger) { // TODO have utils do this
                var detailAssetId = $.anura.getState(this.options.state, 'details');
                if (detailAssetId) {
                    var lightboxSelector = ' a[rel*='+this.options.lightbox_rel+']'+(_this.options.detail_view === 'swipebox'?' img':'');
                    this.element.on('anura-loaded-first.detail-trigger', function() {
                        _this.element.off('anura-loaded-first.detail-trigger');
                        _this.options.detail_trigger = false; // only on first run
                        if (_this.element.find('#anura-asset-id'+detailAssetId).length === 0) {
                            $.anura.getJSON(_this, _this.pageCall.url, {search_id: detailAssetId}, 'anuraAsset'+detailAssetId, function (data, response) {
                                if (data[0]) {
                                    _this.populateContainer(data);
                                    _this.element.find('#anura-asset-id'+detailAssetId).hide().find(lightboxSelector).click();
                                }
                            });
                        } else if (_this.options.detail_view === 'anura') {
                            _this.element.anuraLightbox({action: detailAssetId});
                        } else {
                            _this.element.find('#anura-asset-id'+detailAssetId+lightboxSelector).click();
                        }
                    });
                }
            }
        },

        populateContainer: function(assets) {
            var _this = this;
            this.assets = assets;
            if (assets.length < 1) this.container.addClass('empty');
            else this.container.removeClass('empty');
            if (!this.container.find('.anura-collage-wrapper').length) $('<div />').addClass('anura-collage-wrapper').appendTo(this.container);
            var wrapper = this.container.find('.anura-collage-wrapper');
            $.each(assets, function (i, item) {
                _this.appendAsset(item, wrapper);
            });
            this.addLightbox();
            _this.element.trigger('anura-loaded', this.options);
        },
        addLightbox: function() { // TODO have utils do this
            var _this = this;
            switch(this.options.detail_view) {
                case 'slimbox':
                    this.container.find(".anura-asset-container a[rel^='lightbox']").slimbox(this.options.detail_settings, null, function(el) {
                        return (this == el) || ((this.rel.length > 8) && (this.rel === el.rel));
                    });
                    break;
                case 'swipebox':
                    if (baguetteBox !== undefined) baguetteBox.run('.anura-collage-container', this.options.detail_settings);
                    else this.container.find(".anura-asset-container a[rel^='lightbox']").swipebox(this.options.detail_settings);
                    break;
                case 'fresco':
                    this.container.find(".anura-asset-container a[rel^='lightbox']").each(function(index, item) {
                        var assetId = $(this).closest('.anura-asset-container').data('assetId'), inBasket = ($.inArray(assetId, _this.options.basket.data('assets')) !== -1);
                        $(this).addClass('fresco').attr('data-fresco-group', 'anura'+_this.element.attr('id').replace(/\W/g, ''))
                            .attr('data-fresco-caption', $(this).attr('title')+'<span class="fresco-basket'+(inBasket?' added':'')+'" onclick="' + // this is absolutely terrible, but no other way seems to exist
                                'event.stopPropagation(); $(\'#basket'+assetId+'\').click(); $(this).toggleClass(\'added\');" />');
                    });
                    break;
                case 'spotlight':
                    $.each(_this.options.detail_settings, function(key, value) {_this.container.attr('data-'+key, value)});
                    _this.container.addClass('spotlight-group'); // setting .data(_this.options.detail_settings) doesn't work?
                    _this.container.find(".anura-asset-container a[rel^='lightbox']").addClass('spotlight');
                    break;
                case 'anura':
                    _this.element.anuraLightbox($.extend({}, _this.options.detail_settings, {
                        server: _this.options.server,
                        locale: _this.options.locale,
                        basket: _this.options.basket,
                        trigger: 'a[rel^='+_this.options.lightbox_rel+']',
                        state: _this.options.state,
                        pageCall: _this.pageCall
                    }));
                    break;
                case 'details':
                    $('#colorbox').addClass('hasAnuraDetails');
                case 'colorbox':
                    var infopanel = function(a) {
                        if (_this.options.detail_view !== 'details') return;
                        var panel = $('#anuraInfoPanel');
                        if (!panel.length) {
                            panel = $('<div id="anuraInfoPanel"/>').appendTo('#cboxContent');
                            $('<button type="button" id="cboxInfo"/>').text('info').on('click', function() {
                                $('#anuraInfoPanel').toggle();
                            }).insertBefore($('#cboxClose'));
                        }
                        if (_this.options.colorbox_min_height) var minHeight = Math.min($(window).height() - 50, _this.options.colorbox_min_height); // workaround for missing minHeight option
                        if ($('#cboxLoadedContent').height() < minHeight) $.colorbox.resize({innerHeight: minHeight+'px'});
                        panel.height($('#cboxLoadedContent').height());
                        if ($(window).width() > 767) panel.show(); //argh
                        var asset_container = $.colorbox.element().closest('.anura-asset-container');
                        var options = $.extend({send: _this.options.send, download_directly: _this.options.download_directly}, _this.options.detail_settings,
                            {asset: asset_container.data('assetId') || asset_container.attr('id').replace(/\D/g,''), alternative_name: _this.options.alternative_name.id,
                                server: _this.options.server, locale: _this.options.locale, basket: _this.options.basket});
                        panel.anuraDetails(options);
                    };

                    var colorbox_options = $.extend({transition: 'none', current: '{current} / {total}'}, _this.options.colorbox_settings,
                        {rel: this.options.lightbox_rel, onComplete: infopanel,
                            onCleanup: function() {$('#anuraInfoPanel').fadeOut()},
                            onClosed: function() {$.anura.removeState(_this.options.state, 'details');}
                        });
                    this.container.find('.anura-asset-container a.image').colorbox($.extend(colorbox_options, {maxWidth: '98%', maxHeight: '98%'}));
                    this.container.find('.anura-asset-container a.vimeo, .anura-asset-container a.youtube').colorbox($.extend(colorbox_options, {iframe:true, innerWidth:960, innerHeight:540}));
                    this.container.find('.anura-asset-container a.soundcloud').colorbox($.extend(colorbox_options, {iframe:true, innerWidth:500, innerHeight:500}));
                    this.container.find('.anura-asset-container a.player').colorbox($.extend(colorbox_options, {iframe:true, innerWidth:640, innerHeight:480}));
                    break;
            }
        },
        appendAsset: function(item, target) {
            var name = this.options.alternative_name.always?item.alt_name:item.name, _this = this;
            var container = $('<div />').data('asset-id', item.id).data('asset-ext', item.extension).addClass('anura-asset-container anura-asset-type-'+item.type).appendTo(target);
            // TODO move this to utils
            if (item.infofields) $.each(item.infofields, function(infoId, infoVal) {container.data('asset-infofield-'+infoId, infoVal);});
            if (item.infofields_raw) $.each(item.infofields_raw, function(infoId, infoVal) {container.data('asset-infofield-raw-'+infoId, infoVal);});
            if (item.downloadable === false) container.addClass('anura-not-downloadable');
            if (item.version) container.data('asset-version', item.version).data('asset-versioned', item.versioned);
            if (item.extension) container.data('asset-extension', item.extension);
            if (item.parents) container.data('asset-parents', item.parents);
            if (item.custom) $.each(item.custom.replace(/_/g, '-').split(' '), function(index, value) {container.addClass('anura-custom-'+value);});
            if (_this.options.extended) container.data('asset-extended', item);
            var wrapper = $('<div/>').addClass('anura-image-container').appendTo(container);
            var img = $('<img />').data('id', item.id).addClass('anura-image')
                .attr('src', this.options.server+'/asset'+this.options.ext+'thumb='+item.id+(this.options.target_height > 180?'&big=true':'')+($.anura.tokenProvider?'&token='+$.anura.tokenProvider():'')+'&img=a.jpg');
            if (this.options.detail_view !== 'none') {
                var trigger = $('<a />').attr('rel', this.options.lightbox_rel+' nofollow').data('asset-id', item.id).data('asset-extension', item.extension)
                    .attr('title', name).attr('target', '_blank').appendTo(wrapper);
                if (this.options.detail_view === 'download') {
                    trigger.attr('href', this.options.server+'/asset'+this.options.ext+'download='+item.id+'&format='+this.options.detail_settings.format);
                } else if (item.streaming && item.streaming.soundcloud) {
                    trigger.addClass('soundcloud').attr('href', window.location.protocol+'//w.soundcloud.com/player/?url=http://api.soundcloud.com/tracks/'+item.streaming.soundcloud+'?secret_token='+item.streaming.soundcloud_key+'&visual=true'+(this.options.autoplay?'&auto_play=true':'')+'&buying=false&download=false&show_artwork=true&show_comments=false&show_playcount=false&show_user=false&hide_related=true');
                } else if (item.streaming && item.streaming.vimeo) {
                    trigger.addClass('vimeo').attr('href', window.location.protocol+'//player.vimeo.com/video/'+item.streaming.vimeo+(this.options.autoplay?'?autoplay=1':''));
                } else if (item.streaming && item.streaming.youtube) {
                    trigger.addClass('youtube').attr('href', window.location.protocol+'//www.youtube.com/embed/'+item.streaming.youtube+(this.options.autoplay?'?autoplay=1':''));
                } else if (this.options.stream && (item.type === 3 || item.type === 4)) {
                    trigger.addClass('player').attr('href', this.options.server+'/asset'+this.options.ext+'play='+item.id+(this.options.autoplay?'&autoplay=true':'')+($.anura.tokenProvider?'&token='+$.anura.tokenProvider():''));
                } else {
                    trigger.addClass('image').attr('href', this.options.server+'/asset'+this.options.ext+'preview='+item.id+($.anura.tokenProvider?'&token='+$.anura.tokenProvider():'')+'&img=a.jpg');
                }
                if ($.isFunction(this.options.detail_view)) trigger.on('click', function(e) {e.preventDefault(); _this.options.detail_view(item, trigger)});
                img.appendTo(trigger);
            } else {
                img.appendTo(wrapper);
            }
            if (this.options.caption) $('<div/>').addClass('anura-caption').text(name).appendTo(container);
        },
        showPage: function(page) {
            var _this = this;

            $.extend(this.pageCall.params, {paginate: this.options.paginate, page: page+1});
            $.anura.getJSON(this, this.pageCall.url, this.pageCall.params, this.pageCall.name, function(data, response) {
                _this.container.find('.anura-asset-container').remove();
                var total = response && response.total ? response.total : data.length;
                if (!response && total > _this.options.paginate) data = data.slice((page*_this.options.paginate, (page+1)*_this.options.paginate)); // v1 server
                _this.populateContainer(data, _this.options.paginate);

                _this.container.addClass('anura-loading');
                var items = _this.container.find('.anura-asset-container');
                imagesLoaded(items.get()).on('always', function() {
                    _this.container.collagePlus({
                        images: items,
                        effect        : 'default',
                        fadeSpeed     : 500,
                        targetHeight  : _this.options.target_height,
                        allowPartialLastRow: _this.options.partial_row
                    });
                    if (_this.options.download_menu) { // do that after collagePlus (confuses it otherwise)
                        $.each(items, function(index, item) {_this.addMenu($(this), $(this).data('asset-id'), $(this).data('asset-ext'))});
                    }
                    _this.container.removeClass('anura-loading');
                    if (_this.options.paginate) $.anura.addPaginator(_this, page, total, _this.container.find('.anura-collage-wrapper'));
                    if (page === 0) _this.element.trigger('anura-loaded-first', [_this.options, total]);
                    _this.element.trigger('anura-loaded', [_this.options, data]);
                });
            });

        },
        requestDownloadFormats: function(callback) {
            var _this = this;
            var onComplete = function(data) {
                window.anura_download_formats = _this.download_formats = data;
                if (_this.options.send === true) _this.options.send = data[0].id;
                if (callback) callback();
            }
            if (window.anura_download_formats) { // share globally
                onComplete(window.anura_download_formats);
            } else {
                $.anura.getJSON(this, this.options.server+'/asset'+this.options.ext+'callback=?',
                    {downloadformats: 1, locale: this.options.locale}, 'anuraCollageDlf', onComplete);
            }
        },
        addMenu: function(target, asset, extension) {
            var _this = this;
            var menu = $('<div />').addClass('anura-asset-menu').appendTo(target);
            var holder = $('<div />').addClass('anura-asset-menu-holder').appendTo(menu);
            if (this.download_formats == null) {
                this.requestDownloadFormats(function() {
                    _this.populateMenu(holder, asset);
                });
            } else {
                this.populateMenu(holder, asset);
            }
            target.on('touchstart', function() {
                _this.container.find('.anura-asset-container.anura-touch-hover')
                    .not('.asset'+$(this).data('asset-id')).removeClass('anura-touch-hover');
                $(this).toggleClass('anura-touch-hover');
            });
        },
        populateMenu: function(holder, asset, extension) {
            var _this = this;
            if (this.options.basket) {
                var b_link = $('<a />').addClass('anura-add-basket').attr('title', _this.strings['anura.addToBasket'])
                    .attr('id', 'basket'+asset).appendTo(holder)
                    .on('click', function() {
                        if (b_link.hasClass('added')) {
                            _this.options.basket.anuraBasket({remove: asset});
                            b_link.attr('title', _this.strings['anura.addToBasket']);
                            b_link.removeClass('added');
                        } else {
                            _this.options.basket.anuraBasket({add: asset, force_zip: _this.options.force_zip});
                            b_link.attr('title', _this.strings['anura.removeFromBasket']);
                            b_link.addClass('added');
                        }
                    });
                $('<span />').addClass('anura-asset-menu-button anura-asset-menu-basket').appendTo(b_link);
                if ($.inArray(asset, this.options.basket.data('assets')) !== -1) b_link.addClass('added');
            }
            if (this.options.send) {
                var send = $('<a />').attr('rel', 'nofollow').appendTo(holder)
                    .attr('href', 'mailto:?body='+encodeURIComponent(_this.options.server+'/asset'+_this.options.ext
                        +'download='+asset+'&format='+this.options.send+'&locale='+_this.options.locale
                        +(_this.options.force_zip?'&forcezip=true':'') + ($.anura.tokenProvider ? '&token=' + $.anura.tokenProvider() : '')));
                $('<span />').addClass('anura-asset-menu-button anura-asset-menu-mailto').attr('title', _this.strings['MENUITEMID_MAILTO']).appendTo(send);
            }
            if (this.options.download_directly) {
                $.each(this.download_formats, function(index, format) {
                    if (format.extensions && extension && $.inArray(extension, format.extensions) === -1) return;
                    var base = (format.url)?(format.url+'?'):('asset'+_this.options.ext+'format='+format.id+'&');
                    var link = $('<a />').attr('title', format.name).attr('target', '_blank').attr('rel', 'nofollow').appendTo(holder);
                    if (format.features && $.inArray('editable', format.features) !== -1) {
                        _this.element.anuraCropper({server: _this.options.server, locale: _this.options.locale, assetId: asset.id, downloadFormat: format.id, mode: 'download'});
                    } else {
                        link.attr('href', _this.options.server+'/'+base+'download='+asset.id+'&locale='+_this.options.locale
                            +(_this.options.force_zip?'&forcezip=true':'') + ($.anura.tokenProvider ? '&token=' + $.anura.tokenProvider() : ''))
                            .on('click', function () {$(window).trigger('anura-download', [asset.id, format.id]);});
                    }
                    $('<img />').addClass('anura-asset-menu-button').attr('src', _this.options.server+'/'+_this.options.icon_transform(format.icon)).appendTo(link);
                });
            }
        }
    };
    $.fn[pluginName] = function ( options ) {
        return this.each(function (i, item) { // iterate matches
            var instance = $.data(item, "plugin_" + pluginName);
            if (!instance) { // if it has no instance yet, create it
                $.data(item, "plugin_" + pluginName, new Plugin( item, options ));
            } else { // otherwise merge new options with existing ones, empty and re-init
                instance.options = $.extend( {}, instance.options, options );
                instance.init();
            }
        });
    };
})( jQuery, window, document );

/*!
 *
 * jQuery collagePlus Plugin v0.3.3
 * https://github.com/ed-lea/jquery-collagePlus
 *
 * Copyright 2012, Ed Lea twitter.com/ed_lea
 * http://www.opensource.org/licenses/mit-license.php
 */
;(function(e){e.fn.collagePlus=function(t){function n(t,n,i,s){var o=i.padding*(t.length-1)+t.length*t[0][3],u=i.albumWidth-o,a=u/(n-o),f=o,l=n<i.albumWidth?true:false;for(var c=0;c<t.length;c++){var h=e(t[c][0]),p=Math.floor(t[c][1]*a),d=Math.floor(t[c][2]*a),v=!!(c<t.length-1);if(i.allowPartialLastRow===true&&l===true){p=t[c][1];d=t[c][2]}f+=p;if(!v&&f<i.albumWidth){if(i.allowPartialLastRow===true&&l===true){p=p}else{p=p+(i.albumWidth-f)}}p--;var m=h.is("img")?h:h.find("img");m.width(p);if(!h.is("img")){h.width(p+t[c][3])}m.height(d);if(!h.is("img")){h.height(d+t[c][4])}r(h,v,i);m.one("load",function(e){return function(){if(i.effect=="default"){e.animate({opacity:"1"},{duration:i.fadeSpeed})}else{if(i.direction=="vertical"){var t=s<=10?s:10}else{var t=c<=9?c+1:10}e.removeClass(function(e,t){return(t.match(/\beffect-\S+/g)||[]).join(" ")});e.addClass(i.effect);e.addClass("effect-duration-"+t)}}}(h)).each(function(){if(this.complete)e(this).trigger("load")})}}function r(e,t,n){var r={"margin-bottom":n.padding+"px","margin-right":t?n.padding+"px":"0px",display:n.display,"vertical-align":"bottom",overflow:"hidden"};return e.css(r)}function i(t){$img=e(t);var n=new Array;n["w"]=parseFloat($img.css("border-left-width"))+parseFloat($img.css("border-right-width"));n["h"]=parseFloat($img.css("border-top-width"))+parseFloat($img.css("border-bottom-width"));return n}return this.each(function(){var r=0,s=[],o=1,u=e(this);e.fn.collagePlus.defaults.albumWidth=u.width();e.fn.collagePlus.defaults.padding=parseFloat(u.css("padding-left"));e.fn.collagePlus.defaults.images=u.children();var a=e.extend({},e.fn.collagePlus.defaults,t);a.images.each(function(t){var u=e(this),f=u.is("img")?u:e(this).find("img");var l=typeof f.data("width")!="undefined"?f.data("width"):f.width(),c=typeof f.data("height")!="undefined"?f.data("height"):f.height();var h=i(f);f.data("width",l);f.data("height",c);var p=Math.ceil(l/c*a.targetHeight),d=Math.ceil(a.targetHeight);s.push([this,p,d,h["w"],h["h"]]);r+=p+h["w"]+a.padding;if(r>a.albumWidth&&s.length!=0){n(s,r-a.padding,a,o);delete r;delete s;r=0;s=[];o+=1}if(a.images.length-1==t&&s.length!=0){n(s,r,a,o);delete r;delete s;r=0;s=[];o+=1}})})};e.fn.collagePlus.defaults={targetHeight:400,fadeSpeed:"fast",display:"inline-block",effect:"default",direction:"vertical",allowPartialLastRow:false}})(jQuery);

/*!
 * imagesLoaded PACKAGED v3.0.4
 * JavaScript is all like "You images are done yet or what?"
 * MIT License
 */
(function(){"use strict";function e(){}function t(e,t){for(var n=e.length;n--;)if(e[n].listener===t)return n;return-1}function n(e){return function(){return this[e].apply(this,arguments)}}var i=e.prototype;i.getListeners=function(e){var t,n,i=this._getEvents();if("object"==typeof e){t={};for(n in i)i.hasOwnProperty(n)&&e.test(n)&&(t[n]=i[n])}else t=i[e]||(i[e]=[]);return t},i.flattenListeners=function(e){var t,n=[];for(t=0;e.length>t;t+=1)n.push(e[t].listener);return n},i.getListenersAsObject=function(e){var t,n=this.getListeners(e);return n instanceof Array&&(t={},t[e]=n),t||n},i.addListener=function(e,n){var i,r=this.getListenersAsObject(e),o="object"==typeof n;for(i in r)r.hasOwnProperty(i)&&-1===t(r[i],n)&&r[i].push(o?n:{listener:n,once:!1});return this},i.on=n("addListener"),i.addOnceListener=function(e,t){return this.addListener(e,{listener:t,once:!0})},i.once=n("addOnceListener"),i.defineEvent=function(e){return this.getListeners(e),this},i.defineEvents=function(e){for(var t=0;e.length>t;t+=1)this.defineEvent(e[t]);return this},i.removeListener=function(e,n){var i,r,o=this.getListenersAsObject(e);for(r in o)o.hasOwnProperty(r)&&(i=t(o[r],n),-1!==i&&o[r].splice(i,1));return this},i.off=n("removeListener"),i.addListeners=function(e,t){return this.manipulateListeners(!1,e,t)},i.removeListeners=function(e,t){return this.manipulateListeners(!0,e,t)},i.manipulateListeners=function(e,t,n){var i,r,o=e?this.removeListener:this.addListener,s=e?this.removeListeners:this.addListeners;if("object"!=typeof t||t instanceof RegExp)for(i=n.length;i--;)o.call(this,t,n[i]);else for(i in t)t.hasOwnProperty(i)&&(r=t[i])&&("function"==typeof r?o.call(this,i,r):s.call(this,i,r));return this},i.removeEvent=function(e){var t,n=typeof e,i=this._getEvents();if("string"===n)delete i[e];else if("object"===n)for(t in i)i.hasOwnProperty(t)&&e.test(t)&&delete i[t];else delete this._events;return this},i.removeAllListeners=n("removeEvent"),i.emitEvent=function(e,t){var n,i,r,o,s=this.getListenersAsObject(e);for(r in s)if(s.hasOwnProperty(r))for(i=s[r].length;i--;)n=s[r][i],n.once===!0&&this.removeListener(e,n.listener),o=n.listener.apply(this,t||[]),o===this._getOnceReturnValue()&&this.removeListener(e,n.listener);return this},i.trigger=n("emitEvent"),i.emit=function(e){var t=Array.prototype.slice.call(arguments,1);return this.emitEvent(e,t)},i.setOnceReturnValue=function(e){return this._onceReturnValue=e,this},i._getOnceReturnValue=function(){return this.hasOwnProperty("_onceReturnValue")?this._onceReturnValue:!0},i._getEvents=function(){return this._events||(this._events={})},"function"==typeof define&&define.amd?define(function(){return e}):"object"==typeof module&&module.exports?module.exports=e:this.EventEmitter=e}).call(this),function(e){"use strict";var t=document.documentElement,n=function(){};t.addEventListener?n=function(e,t,n){e.addEventListener(t,n,!1)}:t.attachEvent&&(n=function(t,n,i){t[n+i]=i.handleEvent?function(){var t=e.event;t.target=t.target||t.srcElement,i.handleEvent.call(i,t)}:function(){var n=e.event;n.target=n.target||n.srcElement,i.call(t,n)},t.attachEvent("on"+n,t[n+i])});var i=function(){};t.removeEventListener?i=function(e,t,n){e.removeEventListener(t,n,!1)}:t.detachEvent&&(i=function(e,t,n){e.detachEvent("on"+t,e[t+n]);try{delete e[t+n]}catch(i){e[t+n]=void 0}});var r={bind:n,unbind:i};"function"==typeof define&&define.amd?define(r):e.eventie=r}(this),function(e){"use strict";function t(e,t){for(var n in t)e[n]=t[n];return e}function n(e){return"[object Array]"===c.call(e)}function i(e){var t=[];if(n(e))t=e;else if("number"==typeof e.length)for(var i=0,r=e.length;r>i;i++)t.push(e[i]);else t.push(e);return t}function r(e,n){function r(e,n,s){if(!(this instanceof r))return new r(e,n);"string"==typeof e&&(e=document.querySelectorAll(e)),this.elements=i(e),this.options=t({},this.options),"function"==typeof n?s=n:t(this.options,n),s&&this.on("always",s),this.getImages(),o&&(this.jqDeferred=new o.Deferred);var a=this;setTimeout(function(){a.check()})}function c(e){this.img=e}r.prototype=new e,r.prototype.options={},r.prototype.getImages=function(){this.images=[];for(var e=0,t=this.elements.length;t>e;e++){var n=this.elements[e];"IMG"===n.nodeName&&this.addImage(n);for(var i=n.querySelectorAll("img"),r=0,o=i.length;o>r;r++){var s=i[r];this.addImage(s)}}},r.prototype.addImage=function(e){var t=new c(e);this.images.push(t)},r.prototype.check=function(){function e(e,r){return t.options.debug&&a&&s.log("confirm",e,r),t.progress(e),n++,n===i&&t.complete(),!0}var t=this,n=0,i=this.images.length;if(this.hasAnyBroken=!1,!i)return this.complete(),void 0;for(var r=0;i>r;r++){var o=this.images[r];o.on("confirm",e),o.check()}},r.prototype.progress=function(e){this.hasAnyBroken=this.hasAnyBroken||!e.isLoaded;var t=this;setTimeout(function(){t.emit("progress",t,e),t.jqDeferred&&t.jqDeferred.notify(t,e)})},r.prototype.complete=function(){var e=this.hasAnyBroken?"fail":"done";this.isComplete=!0;var t=this;setTimeout(function(){if(t.emit(e,t),t.emit("always",t),t.jqDeferred){var n=t.hasAnyBroken?"reject":"resolve";t.jqDeferred[n](t)}})},o&&(o.fn.imagesLoaded=function(e,t){var n=new r(this,e,t);return n.jqDeferred.promise(o(this))});var f={};return c.prototype=new e,c.prototype.check=function(){var e=f[this.img.src];if(e)return this.useCached(e),void 0;if(f[this.img.src]=this,this.img.complete&&void 0!==this.img.naturalWidth)return this.confirm(0!==this.img.naturalWidth,"naturalWidth"),void 0;var t=this.proxyImage=new Image;n.bind(t,"load",this),n.bind(t,"error",this),t.src=this.img.src},c.prototype.useCached=function(e){if(e.isConfirmed)this.confirm(e.isLoaded,"cached was confirmed");else{var t=this;e.on("confirm",function(e){return t.confirm(e.isLoaded,"cache emitted confirmed"),!0})}},c.prototype.confirm=function(e,t){this.isConfirmed=!0,this.isLoaded=e,this.emit("confirm",this,t)},c.prototype.handleEvent=function(e){var t="on"+e.type;this[t]&&this[t](e)},c.prototype.onload=function(){this.confirm(!0,"onload"),this.unbindProxyEvents()},c.prototype.onerror=function(){this.confirm(!1,"onerror"),this.unbindProxyEvents()},c.prototype.unbindProxyEvents=function(){n.unbind(this.proxyImage,"load",this),n.unbind(this.proxyImage,"error",this)},r}var o=e.jQuery,s=e.console,a=s!==void 0,c=Object.prototype.toString;"function"==typeof define&&define.amd?define(["eventEmitter/EventEmitter","eventie/eventie"],r):e.imagesLoaded=r(e.EventEmitter,e.eventie)}(window);
