/* © brix cross media AG, http://www.brix.ch - It is strictly forbidden to change, reuse or copy the source code of this document. */
;(function ( $, window, document, undefined ) {
    var pluginName = "anuraGallery",
        defaults = {
            server: 'https://celum.local/anura/first', // REQUIRED, which anura endpoint to use
            ext: '.do?', // extension of server pages (.php, .do)
            node: {kind: 101, id: 0}, // which node of what kind to show (101 = folder, 102 = collection, 103 = keyword)
            top: {number: 0, days: 0}, // show the top X downloads within the last Y days
            relations: {id: 0, version: null, type: null}, // show related assets of a particular asset
            assets: null, // load a defined list of assets from somewhere else
            search: {string: '', node: 0, custom: ''},
            sort: null, // order: one of [id, name, uploaddate, lastmodified, extension, assettype], seq: asc or desc - i.e. {order: 'name', seq: 'asc'}
            locale: '', // ISO 639-1 code, blank for default
            size: 'medium',
            paginate: 12, // how many items to show per page, false to show all, 'auto' to load on scroll
            paginator: ['prev', 'next', 'pages', 'counter'],
            paginator_nav: {prev: '&larr;', next: '&rarr;'},
            autoload_fetch: 50, // how many assets to fetch at once when paginage is set to 'auto'
            limit: 0, // limit the results (or reported total) returned by the server
            detail_view: 'anura', // one of: slimbox, colorbox, details, blank, none
            detail_settings: {}, // settings to pass to anura.details.js
            colorbox_min_height: 500, colorbox_settings: {}, // colorbox specific settings since detail_settings is used by anuraDetails
            download_menu: true, // show the download menu
            download_directly: false, // make the different formats available directly in the menu
            force_zip: false, // force even single asset downloads to be delivered in a ZIP-file
            icon_transform: function(icon) {return icon.replace('/big/', '/small/')},
            alternative_name: { // alternative name (for slimbox etc.)
                id: 0, // information field ID
                always: true, // always use the alternative name, not just for detail view
                tooltip: false // also display it as the title tag on the thumbnails
            },
            basket: null, // object to use as a basket, initialized by a basket plugin
            state: '', // prefix for state in url (multi-instance) or false to disable state
            send: false, // add a mailto-link (ID of the download format to use or true for the first)
            extended: false, // request extended asset properties (size, modified) etc. - has no effect other than that you could use them for sorting
            stream: true, // enables audio and video streaming - use with caution, might overload the server
            vimeo_legacy: false, // treat the informationfield-entry as the vimeo id (for compatibility with old vimeo extension)
            autoplay: true, // whether to automatically start playing (with vimeo and/or stream)
            recursive: false, // load assets from all subnodes recursively (like keywords in 1.x)
            noderef: false, // show assets that have node referencing infofields to this node, 2.x
            infofields: [], // list of information field IDs to load with the list response (use sparingly)
            detail_trigger: true, // listen to the details=... parameter and show the assets details view (regardless of actual navigation context)
            lightbox_rel: 'lightbox-anura', // name of the rel attribute to use for lightbox triggers
            thumbs_as_background: false // show the thumbnail as the background of .anura-image-container instead of an inner <img> tag
        };
    function Plugin( element, options ) {
        this.element = this.container = $(element);
        if (!options.lightbox_rel && options.state) options.lightbox_rel = 'lightbox-anura-'+options.state;
        this.options = $.extend( {}, defaults, options);
        this.strings = {};
        this.strings_locale = this.options.locale;
        this._defaults = defaults;
        this._name = pluginName;
        this.download_formats = null;
        this.pageCall = {};
        this.init();
    }
    Plugin.prototype = {
        init: function() {
            var _this = this;
            if (!$.isEmptyObject(this.strings) && this.options.locale === this.strings_locale) {
                this.loadGallery();
            } else {
                $.anura.getJSON(this, this.options.server+'/asset'+_this.options.ext+'callback=?&string=anura.addToBasket' +
                    '&string=anura.removeFromBasket&string=anura.loadMore&string=MENUITEMID_MAILTO',
                    {locale: this.options.locale}, 'anuraGalleryStrings', function (data) {
                        _this.strings = data;
                        _this.strings_locale = _this.options.locale;
                        _this.loadGallery();
                    });
            }
        },
        loadGallery: function() {
            var existing = this.element.find('.anura-gallery-container'), _this = this;
            if (existing.length > 0) this.container = existing.first();
            else this.container = $('<div />').addClass('anura-gallery-container').appendTo(this.element);

            this.container.removeClass('empty small medium big huge').empty().addClass('anura-loading '+this.options.size)
                .removeClass(function (index, css) {return (css.match (/anura-locale-\S+/g) || []).join(' ');}).addClass('anura-locale-'+this.options.locale);
            this.element.trigger('anura-loading', [this.options]);

            if (this.options.download_directly && this.download_formats == null) this.requestDownloadFormats();

            this.pageCall = {url: this.options.server+'/node'+this.options.ext+'callback=?', name: 'anuraGallery',
                params: {locale: this.options.locale, alt_name: this.options.alternative_name.id, extended: this.options.extended}};
            if (this.options.sort) {
                if (typeof this.options.sort === "string") {
                    var s = this.options.sort.split('_'); this.options.sort = {};
                    this.options.sort.seq = s.pop();
                    this.options.sort.order = s.join('_'); // join again for info_123
                }
                $.extend(this.pageCall.params, {sort_order: this.options.sort.order, sort_order_seq: this.options.sort.seq || 'asc'});
            }
            if (this.options.limit > 0) this.pageCall.params.limit = this.options.limit;
            if (this.options.infofields.length > 0) $.extend(this.pageCall.params, {infofields: this.options.infofields.join(',')});

            if (this.options.assets) {
                this.populateContainer(this.options.assets);
                this.element.trigger('anura-loaded', [this.options, this.options.assets]);
                return;
            } else if (this.options.search && (this.options.search.custom || this.options.search.string)) {
                this.pageCall.name = 'anuraGallerySearch';
                this.pageCall.url = this.options.server+'/node'+this.options.ext+'callback=?'+((this.options.search.custom)?('&'+this.options.search.custom):'');
                $.extend(this.pageCall.params, {search: this.options.search.string, search_node: this.options.search.node});
                this.options.search.string = '';
            } else if (this.options.node && this.options.node.id) {
                this.pageCall.name = 'anuraGalleryNode';
                $.extend(this.pageCall.params, {kind: this.options.node.kind, id: this.options.node.id,
                    recursive: this.options.recursive, noderef: this.options.noderef});
            } else if (this.options.top && this.options.top.number) {
                this.pageCall.name = 'anuraGalleryTopDl';
                $.extend(this.pageCall.params, {top: this.options.top.number, days: this.options.top.days});
            } else if (this.options.relations && this.options.relations.id) {
                this.pageCall.name = 'anuraGalleryRel'+this.options.relations.id;
                $.extend(this.pageCall.params, {relations: this.options.relations.id});
                if (this.options.relations.version) $.extend(this.pageCall.params, {version: this.options.relations.version});
                if (this.options.relations.type) $.extend(this.pageCall.params, {type: this.options.relations.type});
            } else {
                this.container.addClass('empty').removeClass('anura-loading');
                return;
            }
            this.element.data('page-call', this.pageCall);

            this.showPage(0);

            if (this.options.detail_trigger) { // TODO have utils do this
                var detailAssetId = $.anura.getState(this.options.state, 'details');
                if (detailAssetId) {
                    var lightboxSelector = ' a[rel*='+this.options.lightbox_rel+']'+(_this.options.detail_view === 'swipebox'?' img':'');
                    this.element.one('anura-loaded-first', function() {
                        _this.options.detail_trigger = false; // only on first run
                        if (_this.element.find('#anura-asset-id'+detailAssetId).length === 0) {
                            $.anura.getJSON(_this, _this.pageCall.url, {search_id: detailAssetId}, 'anuraAsset' + detailAssetId, function (data, response) {
                                if (data[0]) {
                                    _this.populateContainer(data);
                                    _this.element.find('#anura-asset-id' + detailAssetId).hide().find(lightboxSelector).click();
                                }
                            });
                        } else if (_this.options.detail_view === 'anura') {
                            _this.element.anuraLightbox({action: detailAssetId});
                        } else {
                            _this.element.find('#anura-asset-id'+detailAssetId+' '+lightboxSelector).click();
                        }
                    });
                }
            }
        },
        requestDownloadFormats: function(callback) {
            var _this = this;
            var onComplete = function(data) {
                _this.download_formats = data;
                if (_this.options.send === true) _this.options.send = data[0].id;
                if (callback) callback();
            };
            if (_this.download_formats) {
                onComplete(_this.download_formats);
            } else {
                $.anura.getJSON(this, this.options.server+'/asset'+this.options.ext+'callback=?',
                    {downloadformats: 1, locale: this.options.locale}, 'anuraGalleryDlf', onComplete);
            }
        },
        showPage: function(page) {
            var _this = this;
            this.container.addClass('anura-loading');
            if (_this.options.paginate === 'auto' || _this.options.paginate === 'button') {
                _this.container.find('.anura-autoload').remove();
                var autoload = $('<div/>').addClass('anura-autoload').appendTo(_this.container), autoload_page = page;
                var doInfiniScroll = function() {
                    var button = autoload.find('button');
                    if (button.prop('disabled') === true) return;
                    button.prop('disabled', true);
                    autoload_page = autoload_page + 1;
                    $.extend(_this.pageCall.params, {paginate: _this.options.autoload_fetch, page: autoload_page});
                    $.anura.getJSON(_this, _this.pageCall.url, _this.pageCall.params, _this.pageCall.name, function (data, response) {
                        if (autoload_page === 1) _this.container.find('.anura-asset-container').remove();
                        var total = response && response.total ? response.total : data.length;
                        if (!response && total > _this.options.autoload_fetch) data = data.slice((autoload_page-1)*_this.options.autoload_fetch, autoload_page*_this.options.autoload_fetch); // v1 server
                        _this.populateContainer(data, _this.options.autoload_fetch);
                        button.prop('disabled', false);
                        if (_this.container.find('.anura-asset-container:visible').length >= total) autoload.remove();
                        if (autoload_page === 1) _this.element.trigger('anura-loaded-first', [_this.options, total]);
                        _this.element.trigger('anura-loaded', [_this.options, data]);
                        if (autoload.is(':appeared')) doInfiniScroll(); // do it again if it's still visible
                    }, function () {
                        autoload.remove();
                    });
                };
                if (_this.options.paginate === 'auto') autoload.appear().on('appear', doInfiniScroll);
                $('<button/>').text(_this.strings['anura.loadMore'] || 'load more').addClass(_this.options.button_class).appendTo(autoload).on('click', doInfiniScroll);
                doInfiniScroll();
            } else {
                $.extend(this.pageCall.params, {paginate: this.options.paginate, page: page+1});
                $.anura.getJSON(this, this.pageCall.url, this.pageCall.params, this.pageCall.name, function(data, response) {
                    _this.container.find('.anura-asset-container').remove();
                    var total = response && response.total ? response.total : data.length;
                    if (!response && total > _this.options.paginate) data = data.slice(page*_this.options.paginate, (page+1)*_this.options.paginate); // v1 server
                    _this.populateContainer(data, _this.options.paginate);
                    $.anura.addPaginator(_this, page, total, _this.container.find('.anura-gallery-wrapper'));
                    if (page === 0) _this.element.trigger('anura-loaded-first', [_this.options, total]);
                    _this.element.trigger('anura-loaded', [_this.options, data]);
                });
            }
        },
        populateContainer: function(assets, limit) {
            var _this = this;
            if (!assets || assets.length < 1) {
                this.container.addClass('empty');
            } else {
                this.container.removeClass('empty');
                if (limit && $.isNumeric(limit) && assets.length !== limit) assets = assets.slice(0, limit);
            }
            var wrapper = this.container.find('.anura-gallery-wrapper');
            if (wrapper.length === 0) wrapper = $('<div />').addClass('anura-gallery-wrapper').prependTo(this.container);

            $.each(assets, function (i, item) {
                _this.appendAsset(item, wrapper);
            });
            this.addLightbox();
            this.container.removeClass('anura-loading');
        },
        addLightbox: function() { // TODO have utils do this
            var _this = this;
            switch(this.options.detail_view) {
                case 'slimbox':
                    this.container.find(".anura-asset-container a[rel^='lightbox']").slimbox(this.options.detail_settings, null, function(el) {
                        return (this === el) || ((this.rel.length > 8) && (this.rel === el.rel));
                    });
                    break;
                case 'swipebox':
                    if (baguetteBox !== undefined) baguetteBox.run('.anura-gallery-container', this.options.detail_settings);
                    else this.container.find(".anura-asset-container a[rel^='lightbox']").swipebox(this.options.detail_settings);
                    break;
                case 'spotlight':
                    $.each(_this.options.detail_settings, function(key, value) {_this.container.attr('data-'+key, value)});
                    _this.container.addClass('spotlight-group'); // setting .data(_this.options.detail_settings) doesn't work?
                    _this.container.find(".anura-asset-container a[rel^='lightbox']").addClass('spotlight');
                    break;
                case 'anura':
                    _this.element.anuraLightbox($.extend({}, _this.options.detail_settings, {
                        server: _this.options.server,
                        locale: _this.options.locale,
                        basket: _this.options.basket,
                        trigger: 'a[rel^='+_this.options.lightbox_rel+']',
                        state: _this.options.state,
                        pageCall: _this.pageCall
                    }));
                    break;
                case 'details':
                    $('#colorbox').addClass('hasAnuraDetails');
                case 'colorbox':
                    var infopanel = function(a) {
                        if (_this.options.detail_view !== 'details') return;
                        var panel = $('#anuraInfoPanel');
                        if (!panel.length) {
                            panel = $('<div id="anuraInfoPanel"/>').appendTo('#cboxContent');
                            $('<button type="button" id="cboxInfo"/>').text('info').on('click', function() {
                                $('#anuraInfoPanel').toggle();
                            }).insertBefore($('#cboxClose'));
                        }
                        if (_this.options.colorbox_min_height) var minHeight = Math.min($(window).height() - 50, _this.options.colorbox_min_height); // workaround for missing minHeight option
                        if ($('#cboxLoadedContent').height() < minHeight) $.colorbox.resize({innerHeight: minHeight+'px'});
                        panel.height($('#cboxLoadedContent').height());
                        if ($(window).width() > 767) panel.show(); //argh
                        var asset_container = $.colorbox.element().closest('.anura-asset-container');
                        var options = $.extend({send: _this.options.send, download_directly: _this.options.download_directly}, _this.options.detail_settings,
                            {asset: asset_container.data('assetId') || asset_container.attr('id').replace(/\D/g,''), alternative_name: _this.options.alternative_name.id,
                            server: _this.options.server,locale: _this.options.locale, basket: _this.options.basket});
                        panel.anuraDetails(options);
                    };
                    var colorbox_options = $.extend({transition: 'none', current: '{current} / {total}'}, _this.options.colorbox_settings,
                        {rel: this.options.lightbox_rel, onComplete: infopanel,
                            onCleanup: function() {$('#anuraInfoPanel').fadeOut()},
                            onClosed: function() {$.anura.removeState(_this.options.state, 'details');}
                        });
                    this.container.find('.anura-asset-container a.image').colorbox($.extend(colorbox_options, {maxWidth: '98%', maxHeight: '98%'}));
                    this.container.find('.anura-asset-container a.vimeo, .anura-asset-container a.youtube').colorbox($.extend(colorbox_options, {iframe:true, innerWidth:960, innerHeight:540}));
                    this.container.find('.anura-asset-container a.soundcloud').colorbox($.extend(colorbox_options, {iframe:true, innerWidth:500, innerHeight:500}));
                    this.container.find('.anura-asset-container a.player').colorbox($.extend(colorbox_options, {iframe:true, innerWidth:640, innerHeight:480}));
                    break;
            }
        },
        appendAsset: function(item, target) {
            var _this = this;
            if (item.type > 100) {
                var container = $('<div />').data('asset-id', item.id).addClass('anura-asset-container anura-asset-type-'+item.type).appendTo(target);
                var holder = $('<div />').addClass('anura-node-container').appendTo(container)
                    .on('click', function() {
                        if ($('#anura-node-'+item.id).length) $('#anura-node-'+item.id+' > a').click();
                        _this.element.anuraGallery({node: {id: item.id, kind: item.type}});
                    });
                var tag = (item.custom?item.custom:'!default')+'/large.png';
                var tag_type = (this.options.node.kind === 103?'keyword':(this.options.node.kind === 102?'assetcollection':'folder'));
                $('<img>').attr('src', this.options.server+'/../img/aci/'+tag_type+'/'+tag).addClass('anura-node').appendTo(holder);
                $('<p />').addClass('anura-node-name').text(item.name).attr('title', item.name).appendTo(container);
                return;
            }
            var name = this.options.alternative_name.always?item.alt_name:item.name,
                tooltip = this.options.alternative_name.tooltip?item.alt_name:item.name;
            var container = $('<div />').data('asset-id', item.id).attr('id', 'anura-asset-id'+item.id)
                .addClass('anura-asset-container anura-asset-type-'+item.type).appendTo(target);
            if (item.infofield) container.data('asset-infofield', item.infofield); // legacy
            // TODO move this to utils
            if (item.infofields) $.each(item.infofields, function(infoId, infoVal) {container.data('asset-infofield-'+infoId, infoVal);});
            if (item.infofields_raw) $.each(item.infofields_raw, function(infoId, infoVal) {container.data('asset-infofield-raw-'+infoId, infoVal);});
            if (item.downloadable === false) container.addClass('anura-not-downloadable');
            if (item.version) container.data('asset-version', item.version).data('asset-versioned', item.versioned);
            if (item.extension) container.data('asset-extension', item.extension);
            if (item.parents) container.data('asset-parents', item.parents);
            if (_this.options.extended) container.data('asset-extended', item);
            if (item.custom) $.each(item.custom.replace(/_/g, '-').split(' '), function(index, value) {container.addClass('anura-custom-'+value);});
            if (this.options.download_menu) this.addMenu(container, item);
            if (this.options.vimeo_legacy && (item.infofield || item.vimeo)) {
				if (!item.streaming) item.streaming = {};
				if (!item.streaming.vimeo) item.streaming.vimeo = item.infofield || item.vimeo;
			}
            var holder = $('<div />').addClass('anura-image-container').appendTo(container);
            var imgSrc = this.options.server + '/asset' + this.options.ext + 'thumb=' + item.id + (_this.options.size === 'huge' ? '&big=true' : '') + ($.anura.tokenProvider ? '&token=' + $.anura.tokenProvider() : '') + '&img=a.jpg';
            if (this.options.thumbs_as_background) {
                holder.css('background-image', 'url(\''+imgSrc+'\')');
            } else {
                var img = $('<img />').data('id', item.id).attr('alt', tooltip).addClass('anura-image').attr('loading', 'lazy').attr('src', imgSrc)
                    /* IE */.removeAttr('width').removeAttr('height')/* /IE */;
            }
            if (this.options.detail_view !== 'none') {
                var trigger = $('<a />').attr('rel', this.options.lightbox_rel+' nofollow').data('asset-id', item.id).data('asset-extension', item.extension)
                                        .attr('title', tooltip).attr('target', '_blank').appendTo(holder);
                if (this.options.detail_view === 'download') {
                    trigger.attr('href', this.options.server+'/asset'+this.options.ext+'download='+item.id+'&format='+this.options.detail_settings.format);
                } else if (item.streaming && item.streaming.soundcloud && item.type === 4) {
                    trigger.addClass('soundcloud').attr('href', window.location.protocol+'//w.soundcloud.com/player/?url=http://api.soundcloud.com/tracks/'+item.streaming.soundcloud+'?secret_token='+item.streaming.soundcloud_key+'&visual=true'+(this.options.autoplay?'&auto_play=true':'')+'&buying=false&download=false&show_artwork=true&show_comments=false&show_playcount=false&show_user=false&hide_related=true');
                } else if (item.streaming && item.streaming.vimeo && item.type === 3) {
                    trigger.addClass('vimeo').attr('href', window.location.protocol+'//player.vimeo.com/video/'+item.streaming.vimeo+(this.options.autoplay?'?autoplay=1':''));
                } else if (item.streaming && item.streaming.youtube && item.type === 3) {
                    trigger.addClass('youtube').attr('href', window.location.protocol+'//www.youtube.com/embed/'+item.streaming.youtube+(this.options.autoplay?'?autoplay=1':''));
                } else if (this.options.stream && (item.type === 3 || item.type === 4)) {
                    trigger.addClass('player').attr('href', this.options.server+'/asset'+this.options.ext+'play='+item.id+(this.options.autoplay?'&autoplay=true':'')+($.anura.tokenProvider?'&token='+$.anura.tokenProvider():''));
                } else {
                    trigger.addClass('image').attr('href', this.options.server+'/asset'+this.options.ext+'preview='+item.id+($.anura.tokenProvider?'&token='+$.anura.tokenProvider():'')+'&img=a.jpg');
                }
                if ($.isFunction(this.options.detail_view)) trigger.on('click', function(e) {e.preventDefault(); _this.options.detail_view(item, trigger)});
                if (img) img.appendTo(trigger);
            } else if (img) {
                img.appendTo(holder);
            }
            $('<p />').addClass('anura-asset-name').text(name).attr('title', name).appendTo(container);
            return container;
        },
        addMenu: function(target, asset) {
            var _this = this;
            var menu = $('<div />').addClass('anura-asset-menu').appendTo(target);
            var holder = $('<div />').addClass('anura-asset-menu-holder').appendTo(menu);
            if (this.options.download_directly && this.download_formats == null) {
                this.requestDownloadFormats(function() {
                    _this.populateMenu(holder, asset);
                });
            } else {
                this.populateMenu(holder, asset);
            }
            target.on('touchstart', function() {
                _this.container.find('.anura-asset-container.anura-touch-hover')
                    .not('.asset'+$(this).data('asset-id')).removeClass('anura-touch-hover');
                $(this).toggleClass('anura-touch-hover');
            });
        },
        populateMenu: function(holder, asset) {
            var _this = this;
            if (this.options.basket) {
                var b_link = $('<a />').addClass('anura-add-basket').attr('title', _this.strings['anura.addToBasket'] || 'add to basket')
                    .attr('id', 'basket'+asset.id).appendTo(holder)
                    .on('click', function() {
                        if (b_link.hasClass('added')) {
                            _this.options.basket.anuraBasket({remove: asset.id});
                            b_link.attr('title', _this.strings['anura.addToBasket'] || 'add to basket');
                            b_link.removeClass('added');
                        } else {
                            _this.options.basket.anuraBasket({add: asset.id, force_zip: _this.options.force_zip});
                            b_link.attr('title', _this.strings['anura.removeFromBasket'] || 'remove from basket');
                            b_link.addClass('added');
                        }
                    });
                $('<span />').addClass('anura-asset-menu-button anura-asset-menu-basket').appendTo(b_link);
                if ($.inArray(asset.id, this.options.basket.data('assets')) !== -1) b_link.addClass('added');
            }
            if (this.options.send) {
                var send = $('<a />').attr('rel', 'nofollow').appendTo(holder)
                    .attr('href', 'mailto:?body='+encodeURIComponent(_this.options.server+'/asset'+_this.options.ext
                        +'download='+asset.id+'&format='+this.options.send+'&locale='+_this.options.locale
                        +(_this.options.force_zip?'&forcezip=true':'') + ($.anura.tokenProvider ? '&token=' + $.anura.tokenProvider() : '')));
                $('<span />').addClass('anura-asset-menu-button anura-asset-menu-mailto')
                    .attr('title', _this.strings['MENUITEMID_MAILTO'] || 'send hyperlink').appendTo(send);
            }
            if (this.options.download_directly) {
                $.each(this.download_formats, function(index, format) {
                    if (format.extensions && asset.extension && $.inArray(asset.extension, format.extensions) === -1) return;
                    var base = (format.url)?(format.url+'?'):('asset'+_this.options.ext+'format='+format.id+'&');
                    var link = $('<a />').attr('title', format.name).attr('target', '_blank').attr('rel', 'nofollow').appendTo(holder);
                    if (format.features && $.inArray('editable', format.features) !== -1) {
                        _this.element.anuraCropper({server: _this.options.server, locale: _this.options.locale, assetId: asset.id, downloadFormat: format.id, mode: 'download'});
                    } else {
                        link.attr('href', _this.options.server+'/'+base+'download='+asset.id+'&locale='+_this.options.locale
                            +(_this.options.force_zip?'&forcezip=true':'') + ($.anura.tokenProvider ? '&token=' + $.anura.tokenProvider() : ''))
                            .on('click', function () {$(window).trigger('anura-download', [asset.id, format.id]);});
                    }
                    $('<img />').addClass('anura-asset-menu-button').attr('src', _this.options.server+'/'+_this.options.icon_transform(format.icon)).appendTo(link);
                });
            }
        }
    };
    $.fn[pluginName] = function ( options ) {
        return this.each(function (i, item) { // iterate matches
            var instance = $.data(item, "plugin_" + pluginName);
            if (!instance) { // if it has no instance yet, create it
                $.data(item, "plugin_" + pluginName, new Plugin( item, options ));
            } else { // otherwise merge new options with existing ones, empty and re-init
                instance.options = $.extend( {}, instance.options, options );
                instance.init();
            }
        });
    };
})( jQuery, window, document );

/*!
 * jQuery appear plugin
 * Copyright (c) 2012 Andrey Sidorov, licensed under MIT license.
 * https://github.com/morr/jquery.appear, version: 0.3.6
 */
(function($){var selectors=[];var check_binded=false;var check_lock=false;var defaults={interval:250,force_process:false};var $window=$(window);var $prior_appeared=[];function process(){check_lock=false;for(var index=0,selectorsLength=selectors.length;index<selectorsLength;index++){var $appeared=$(selectors[index]).filter(function(){return $(this).is(':appeared')});$appeared.trigger('appear',[$appeared]);if($prior_appeared[index]){var $disappeared=$prior_appeared[index].not($appeared);$disappeared.trigger('disappear',[$disappeared])}$prior_appeared[index]=$appeared}};function add_selector(selector){selectors.push(selector);$prior_appeared.push()}$.expr[':']['appeared']=function(element){var $element=$(element);if(!$element.is(':visible')){return false}var window_left=$window.scrollLeft();var window_top=$window.scrollTop();var offset=$element.offset();var left=offset.left;var top=offset.top;if(top+$element.height()>=window_top&&top-($element.data('appear-top-offset')||0)<=window_top+$window.height()&&left+$element.width()>=window_left&&left-($element.data('appear-left-offset')||0)<=window_left+$window.width()){return true}else{return false}};$.fn.extend({appear:function(options){var opts=$.extend({},defaults,options||{});var selector=this.selector||this;if(!check_binded){var on_check=function(){if(check_lock){return}check_lock=true;setTimeout(process,opts.interval)};$(window).scroll(on_check).resize(on_check);check_binded=true}if(opts.force_process){setTimeout(process,opts.interval)}add_selector(selector);return $(selector)}});$.extend({force_appear:function(){if(check_binded){process();return true}return false}})})(function(){if(typeof module!=='undefined'){return require('jquery')}else{return jQuery}}());
