/* © brix cross media AG, http://www.brix.ch - It is strictly forbidden to change, reuse or copy the source code of this document. */
;(function ( $, window, document, undefined ) {
    var pluginName = "anuraLightbox",
        defaults = {
            server: 'https://celum.local/anura/first', // REQUIRED, which anura endpoint to use
            ext: '.do?', // extension of server pages (.php, .do)
            locale: '', // ISO 639-1 code, blank for default
            basket: null,
            trigger: 'a[rel^=anura-lightbox]',
            toolbar: {
                available: true,
                visible: true,
                layout: ['title', 'counter', /*'share',*/ 'download', /*'fullscreen',*/ 'basket', 'sidebar', 'close']
            },
            sidebar: {
                available: true,
                visible: true,
                settings: {},
                // callback(options, sidebar, asset)
            },
            navigation: {
                keyboard: true, // navigate with keyboard shortcuts
                click: true, // navigate by clicking on the image
                buttons: true // floating buttons over the embed
            },
            carousel: {
                available: false,
                visible: false,
                settings: {},
            },
            theme: 'light', // or 'dark'
            pageCall: {},
            pdfPreviews: navigator.pdfViewerEnabled || false, // show PDFs in the browsers native PDF viewer
            nativePlayer: true, // show audio/video content in the native player instead of CELUMs
            slideshowMillis: 5000,
            downloadFormat: 1,
            highres: $(window).width() > 2048 || $(window).height() > 2048,
            preview3D: null, // ['glb', 'gltf', 'usdz'] - enabling this will load an external preview library from unpkg.com/@google
            action: null, // show, hide, toggle, sidebar, toolbar, theme, remove, {object}, <assetId>
            state: ''
        };
    function Plugin( element, options ) {
        this.element = this.container = $(element);
        this.options = $.extend( {}, defaults, options );
        if (this.strings === undefined) this.strings = [];
        this.strings_locale = this.options.locale;
        this.overlay = null;
        this.embed = null, embed_wrapper = null;
        this.sidebar = null;
        this.carousel = null;
        this.assetId = null, sidebarAssetId = null;
        this.title = null, this.counter = null;
        this.basketButton = null, this.shareButton = null;
        this.triggers = [], currentIndex = null;
        this.slideshowInterval = null;
        this._defaults = defaults;
        this._name = pluginName;
        this.init();
    }
    Plugin.prototype = {
        init: function() {
            var _this = this;
            if (!this.options.sidebar.callback) {
                this.options.sidebar.callback = function(options, sidebar, asset) {
                    sidebar.anuraDetails($.extend({server: options.server, locale: options.locale, basket: options.basket, state: options.state},
                        options.sidebar.settings, {caller: _this, asset: asset}));
                };
            }
            if (!$.isEmptyObject(this.strings) && this.options.locale === this.strings_locale) {
                _this.loadLightbox();
            } else {
                $.anura.getJSON(this, this.options.server + '/asset' + this.options.ext + 'callback=?&string=' +
                        ['MENUITEMID_DOWNLOAD', 'downloadformatgroup.all.downloadFormat', 'downloadformatmanagement.downloadformat.name', 'search.cleanUp', 'assetlist.viewsettings',
                         'MENUITEMID_SEND', 'MENUITEMID_MAILTO', 'common.form.inactive', 'loading.general', 'general.close', 'MENUITEMID_SHOW_FULLSCREEN_PREVIEW', 'anura.carousel',
                         'anura.addToBasket', 'anura.removeFromBasket', 'general.previous', 'general.next', 'actionmenu.sidebar.enable', 'common.copyToClipboard'].join('&string='),
                    {locale: this.options.locale}, 'anuraLightboxStrings', function (data) {
                        _this.strings = data;
                        if (_this.strings_locale && _this.strings_locale !== _this.options.locale) {
                            _this.overlay.remove(); _this.overlay = null;
                        }
                        _this.strings_locale = _this.options.locale;
                        _this.loadLightbox();
                    }, function () {
                        _this.loadLightbox();
                    });
            }
        },
        loadLightbox: function() {
            var _this = this;
            if (this.overlay == null) {
                this.overlay = $('<div />').addClass('anura-lightbox-overlay anura-lightbox-theme-' + this.options.theme).appendTo($('body'));
                if (this.options.navigation.keyboard) $(document).on('keydown', function (e) {
                    if (_this.isVisible() && (!e.target || $.inArray(e.target.tagName, ['TEXTAREA', 'INPUT']) === -1)) {
                        //console.log(e.keyCode);
                        switch (e.keyCode) {
                            case 81: // q
                            case 27: _this.hide(); break; //esc
                            case 72: // h (vim)
                            case 37: _this.prev(); break; //left
                            case 76: // l (vim)
                            case 39: _this.next(); break; //right
                            case 66: if (_this.basketButton) _this.basketButton.click(); break; //b
                            case 83: _this.toggleSidebar(); break; // s
                            case 73: _this.toggleTheme(); break; // i
                            case 84: _this.toggleToolbar(); break; // t
                        }
                    }
                });
                if (this.options.toolbar && this.options.toolbar.available) {
                    var toolbar = $('<div />').addClass('anura-lightbox-toolbar').appendTo(this.overlay);
                    this.overlay.toggleClass('anura-has-toolbar', this.options.toolbar.visible);

                    if ($.inArray('close', this.options.toolbar.layout) === -1) this.options.toolbar.layout.push('close');
                    $.each(this.options.toolbar.layout.slice().reverse(), function (index, button) {
                        switch (button) {//['title', 'counter', 'share', 'download', /*'fullscreen',*/ 'basket', 'sidebar', 'close']
                            case 'title':
                                _this.title = $('<span/>').addClass('anura-lightbox-title').appendTo(toolbar);
                                break;
                            case 'counter':
                                _this.counter = $('<span/>').addClass('anura-lightbox-counter').appendTo(toolbar);
                                break;
                            case 'share':
                                _this.shareButton = _this.addButton(toolbar, 'anura-lightbox-share', $.anura.icons.share,
                                    _this.strings['common.copyToClipboard']).attr('rel', 'nofollow').attr('data-clipboard-text', '#');
                                var setLinkState = function (e, clazz) {
                                    _this.shareButton.removeClass('anura-success anura-error').addClass(clazz);
                                    setTimeout(function () {_this.shareButton.removeClass('anura-success anura-error')}, 2500);
                                };
                                new ClipboardJS('.anura-lightbox-share')
                                    .on('success', function(e) {setLinkState(e, 'anura-success');})
                                    .on('error', function(e) {setLinkState(e, 'anura-error');});
                                break;
                            case 'download':
                                _this.addButton(toolbar, 'anura-lightbox-download', $.anura.icons.download, _this.strings['MENUITEMID_DOWNLOAD'] || 'Download').on('click', function () {
                                    var linkUrl = '&download='+_this.assetId+'&locale='+_this.options.locale+($.anura.tokenProvider?'&token='+$.anura.tokenProvider():'')+(_this.options.force_zip?'&forcezip=true':'');
                                    window.open(_this.options.server+'/asset'+_this.options.ext+'format='+_this.options.downloadFormat+linkUrl, '_blank');
                                    $(window).trigger('anura-download', [_this.assetId, _this.options.downloadFormat]);
                                }); // TODO add download format selector
                                break;
                            case 'fullscreen':
                                _this.addButton(toolbar, 'anura-lightbox-fullscreen', $.anura.icons.fullscreen, 'Fullscreen').on('click', function () {
                                    if (_this.embed) _this.embed[0].requestFullscreen();
                                });
                                break;
                            case 'basket':
                                if (_this.options.basket) {
                                    _this.basketButton = _this.addButton(toolbar, 'anura-lightbox-add-to-basket', $.anura.icons.basket, _this.strings['anura.addToBasket'] ||  'Basket').on('click', function () {
                                        if (_this.basketButton.hasClass('added')) _this.options.basket.anuraBasket({remove: _this.assetId});
                                        else _this.options.basket.anuraBasket({add: _this.assetId});
                                    });
                                    _this.options.basket.on('anura-asset-added anura-asset-removed anura-cleared', function (e) {
                                        _this.setBasketState();
                                    });
                                }
                                break;
                            case 'sidebar':
                                if (_this.options.sidebar.available) {
                                    _this.addButton(toolbar, 'anura-lightbox-toggle-sidebar', $.anura.icons.sidebar, _this.strings['actionmenu.sidebar.enable'] || 'Info').on('click', function () {
                                        _this.toggleSidebar();
                                    });
                                }
                                break;
                            case 'theme':
                                _this.addButton(toolbar, 'anura-lightbox-toggle-theme', $.anura.icons.sun, _this.strings['assetlist.viewsettings'] || 'Theme').on('click', function () {
                                    _this.toggleTheme();
                                });
                                break;
                            case 'prev':
                                _this.addButton(toolbar, 'anura-lightbox-toggle-prev', $.anura.icons.left, _this.strings['general.previous']).on('click', function () {
                                    _this.prev();
                                });
                                break;
                            case 'next':
                                _this.addButton(toolbar, 'anura-lightbox-toggle-next', $.anura.icons.right, _this.strings['general.next']).on('click', function () {
                                    _this.prev();
                                });
                                break;
                            case 'slideshow':
                                var slideshowButton = _this.addButton(toolbar, 'anura-lightbox-slideshow', $.anura.icons.play, _this.strings['anura.slideshow'] || 'Slideshow').on('click', function () {
                                    if (slideshowButton.hasClass('anura-playing')) {
                                        clearInterval(_this.slideshowInterval);
                                    } else {
                                        _this.next();
                                        _this.slideshowInterval = setInterval(function () {
                                            _this.next();
                                        }, _this.options.slideshowMillis);
                                    }
                                    slideshowButton.toggleClass('anura-playing');
                                });
                                break;
                            case 'carousel':
                                _this.addButton(toolbar, 'anura-lightbox-toolbar-carousel', $.anura.icons.carousel, _this.strings['anura.carousel'] || 'Carousel').on('click', function () {
                                    _this.overlay.toggleClass('anura-has-carousel');
                                });
                                break;
                            case 'close':
                                _this.addButton(toolbar, 'anura-lightbox-close', $.anura.icons.close, _this.strings['general.close'] || 'Close').on('click', function () {
                                    _this.hide();
                                });
                                break;
                            default:
                                if ($.isFunction(button)) {
                                    button(_this.options, toolbar);
                                } else {
                                    console.log('Unknown toolbar feature: '+button);
                                }
                        }
                    });
                }
                var container = $('<div />').addClass('anura-lightbox-container').appendTo(this.overlay);
                var embed_container = $('<div />').addClass('anura-lightbox-embed-container').appendTo(container)
                    .swipe({
                        tap: function (e) {
                            if (!_this.options.navigation.click || $(e.target).prop("tagName") !== "EMBED" /*otherwise it interferes with the buttons */) return;
                            if (e.clientX && e.clientX / embed_container.width() < 0.5) _this.prev();
                            else _this.next();
                        }, swipeLeft: function (e) {
                            if ($(e.target).prop("tagName") !== "EMBED") return;
                            _this.next();
                        }, swipeRight: function (e) {
                            if ($(e.target).prop("tagName") !== "EMBED") return;
                            _this.prev();
                        }
                        /*swipe:function(event, direction, distance, duration, fingerCount, fingerData) {
                            console.log("You swiped " + direction );
                        },*/
                    });

                // prev / next buttons
                if (this.options.navigation.buttons) {
                    var prev = $('<div/>').addClass('anura-lightbox-nav anura-lightbox-nav-left anura-lightbox-svg')
                        .appendTo(embed_container).on('click', function () {
                        _this.prev()
                    }).attr('title', this.strings['general.previous']);
                    $($.anura.icons.left).appendTo(prev);
                    var next = $('<div/>').addClass('anura-lightbox-nav anura-lightbox-nav-right anura-lightbox-svg')
                        .appendTo(embed_container).on('click', function () {
                        _this.next()
                    }).attr('title', this.strings['general.next']);
                    $($.anura.icons.right).appendTo(next);
                }

                this.embed_wrapper = $('<div />').addClass('anura-lightbox-embed').appendTo(embed_container);

                if (this.options.carousel && this.options.carousel.available) {
                  this.carousel = $('<div />').addClass('anura-lightbox-carousel').appendTo(embed_container);
                  this.overlay.toggleClass('anura-has-carousel', this.options.carousel.visible);
                }

                if (this.options.sidebar && this.options.sidebar.available) {
                    this.sidebar = $('<div />').addClass('anura-lightbox-sidebar').data('anura-lightbox-owner', this.container).appendTo(container);
                    this.overlay.toggleClass('anura-has-sidebar', this.options.sidebar.visible).toggleClass('anura-no-sidebar', !this.options.sidebar.visible);
                }

                if (this.options.preview3D) {
                    $('<script type="module" src="https://unpkg.com/@google/model-viewer/dist/model-viewer.min.js"></script>').appendTo($('body'));
                }
            }
            this.triggers = $(this.options.trigger);
            this.triggers.off('click.anura-lightbox').on('click.anura-lightbox', function (e) {
                e.preventDefault();
                _this.showAsset($(this));
            });
            if (this.options.carousel && this.options.carousel.available && this.triggers) {
                this.carousel.empty();
                var appendTrigger = function (trigger, target, counter) {
                    $('<img class="anura-lightbox-carousel-item">')
                        .attr('id', 'anura-lightbox-carousel-item-'+counter)
                        .attr('src', trigger.attr('href').replaceAll('preview', 'thumb'))
                        .attr('title', trigger.attr('title')).appendTo(target)
                        .on('click', function () {trigger.click()})
                        .one('load', function () {_this.updateCarouselPosition()});
                }
                for (var i = 0; i < this.triggers.length; i++) {
                    appendTrigger($(this.triggers[i]), this.carousel, i);
                }
            }
            if (this.options.action) {
                switch (this.options.action) {
                    case 'show': this.show(); break;
                    case 'hide': this.hide(); break;
                    case 'toggle': this.isVisible() ? this.hide() : this.show(); break;
                    case 'sidebar': this.toggleSidebar(); break;
                    case 'toolbar': this.toggleToolbar(); break;
                    case 'theme': this.toggleTheme(); break;
                    case 'remove': this.remove(); break;
                }
                if (typeof this.options.action === "object") {
                    this.embed.remove();
                    if (this.options.action.title) this.title.text(this.options.action.title);
                    if (this.options.action.url) this.setEmbedContent(this.options.action.url,
                            this.options.action.mime ? this.options.action.mime : 'image/jpeg');
                } else if ($.isNumeric(this.options.action)) {
                    this.assetId = this.options.action;
                    var trigger = $('#anura-asset-id'+this.options.action+' a[rel], [data-asset-id='+this.options.action+']').first();
                    if (trigger.length) {
                        this.showAsset(trigger);
                    } else {
                        $.anura.getJSON(_this, this.options.server + '/asset' + this.options.ext + 'callback=?&details='+this.assetId
                            +($.anura.tokenProvider?'&token='+$.anura.tokenProvider():''),{},'anuraLightboxAsset'+this.assetId,
                            function (data) {
                                var virtual_wrapper = $('<div>').addClass('anura-asset-container').data('assetId', _this.assetId);
                                var virtual_trigger = $('<a>').attr('title', data.name).attr('src', _this.options.server + '/asset' + _this.options.ext + 'preview=' +_this.assetId
                                    + (_this.options.highres ? '&big=true' : '') + ($.anura.tokenProvider?'&token='+$.anura.tokenProvider():'')).appendTo(virtual_wrapper);
                                $.each(data.general, function(index, value) {if (value.id === 'file_type') virtual_wrapper.addClass('anura-asset-type-'+value.raw);});
                                _this.showAsset(virtual_trigger);
                            });
                    }
                }
                this.options.action = null;
            }
            this.element.trigger('anura-loaded', [_this.options]);
        },
        show: function() {
            if (!this.isVisible()) {
                this.overlay.addClass('anura-lightbox-visible');
                this.element.trigger('anura-lightbox-show', [this.options]);
                $('body').addClass('anura-lightbox-noscroll');
                if (this.assetId) $.anura.setState(this.options.state, 'details', this.assetId);
            }
        },
        hide: function() {
            if (this.isVisible()) {
                this.overlay.removeClass('anura-lightbox-visible');
                if (this.embed && this.embed.attr('type') !== 'image/jpeg') this.embed.remove(); // no good way to stop playing videos -> unload it
                if (this.slideshowInterval) clearInterval(this.slideshowInterval);
                this.element.trigger('anura-lightbox-hide', [this.options]);
                $('body').removeClass('anura-lightbox-noscroll');
                $.anura.removeState(this.options.state, 'details');
            }
        },
        remove: function () {
            if (this.triggers) this.triggers.off('click.anura-lightbox');
            this.element.removeData("plugin_" + pluginName);
            this.overlay.remove();
        },
        isVisible: function() {
            return this.overlay.hasClass('anura-lightbox-visible');
        },
        toggleSidebar: function() {
            if (this.options.sidebar && this.options.sidebar.available) {
                if (this.sidebarAssetId !== this.assetId && this.options.sidebar.callback) {
                    this.options.sidebar.callback($.extend(true, {}, this.options), this.sidebar, this.assetId);
                }
                this.overlay.toggleClass('anura-has-sidebar').toggleClass('anura-no-sidebar');
                this.element.trigger('anura-lightbox-sidebar-toggled', [this.options, this.hasSidebar()]);
            }
        },
        hasSidebar: function() {
            return this.overlay.hasClass('anura-has-sidebar');
        },
        toggleToolbar: function() {
            if (this.options.toolbar) {
                this.overlay.toggleClass('anura-has-toolbar');
                this.element.trigger('anura-lightbox-toolbar-toggled', [this.options, this.hasToolbar()]);
            }
        },
        hasToolbar: function() {
            return this.overlay.hasClass('anura-has-toolbar');
        },
        toggleTheme: function() {
            if (this.options.theme === 'dark' || this.options.theme === 'light') {
                this.overlay.toggleClass('anura-lightbox-theme-dark anura-lightbox-theme-light');
            } else {
                this.overlay.toggleClass('anura-lightbox-theme-' + this.options.theme);
            }
        },
        showAsset: function(trigger) {
            var _this = this;
            if (!trigger) return;
            this.overlay.addClass('anura-loading');
            if (trigger.data('asset-id')) this.assetId = trigger.data('asset-id');
            this.findCurrentIndex();
            if (this.title) this.title.text(this.strings['loading.general'] || 'Loading...').attr('title', '');
            var count = this.triggers.length || 1;
            this.overlay.find('.anura-lightbox-nav').toggleClass('anura-nav-superfluous', count <= 1);
            if (this.counter) this.counter.html(count > 1 ? (1+(this.currentIndex || 0) + '&thinsp;/&thinsp;' + count) : '');
            var url = (trigger.attr('href') || this.options.server + '/asset' + this.options.ext + 'preview=' +this.assetId) + (this.options.highres ? '&big=true' : '');
            var container = trigger.parents('.anura-asset-container');
            var celumPlayer = trigger.hasClass('player');
            if (celumPlayer && this.options.nativePlayer) {
                url = url.replace('play=', 'stream=');
                celumPlayer = false;
            }

            if (this.options.pdfPreviews && container.hasClass('anura-asset-type-2')) { // documents
                var searchState = ($.anura.hasState(this.options.state, 'search-text') ? ('#search=' + encodeURIComponent($.anura.getState(this.options.state, 'search-text'))) : '');
                this.setEmbedContent(url + '&type=pdf'+searchState, 'application/pdf', url, 'image/jpeg');
            } else if (!celumPlayer && container.hasClass('anura-asset-type-3')) { // video
                this.setEmbedContent(url + '&type=video', 'video/mp4', url, 'image/jpeg');
            } else if (!celumPlayer && container.hasClass('anura-asset-type-4')) { // audio
                this.setEmbedContent(url + '&type=audio', 'audio/mpeg', url, 'image/jpeg')
            } else if (celumPlayer && (container.hasClass('anura-asset-type-4') || container.hasClass('anura-asset-type-3'))) { // celum player
                this.setEmbedContent(url, 'text/html', url, 'image/jpeg')
            } else if (this.options.preview3D && this.options.preview3D.indexOf(trigger.data('asset-extension')) !== -1) {
                this.setEmbedContent(url + '&type=3D', 'model/gltf-binary');
            } else {
                this.setEmbedContent(url, 'image/jpeg');
            }

            var title = trigger.attr('title'); this.embed.attr('title', title);
            if (this.title) this.title.text(title).attr('title', title);
            if (this.options.sidebar && this.hasSidebar()) {
                this.sidebarAssetId = this.assetId; // to detect if we're out of sync due to toggleSidebar
                if (this.options.sidebar.callback) this.options.sidebar.callback(this.options, this.sidebar, this.assetId);
            }
            this.setBasketState();
            if (!this.isVisible()) this.show();
            $.anura.setState(this.options.state, 'details', this.assetId);
            if (_this.shareButton) _this.shareButton.attr('data-clipboard-text', window.location.href);
            _this.updateCarouselPosition();
            this.element.trigger('anura-lightbox-show-asset', [this.options, this.assetId, url, title]);
        },
        setEmbedContent: function(url, mime, fallback_url, fallback_mime) {
            var _this = this;
            if (this.embed && this.embed.attr('type') !== 'image/jpeg') this.embed.remove(); // no good way to stop playing videos from prev embed -> unload it
            var existing = this.embed_wrapper.find('#anura-lightbox-embed-'+this.assetId);
            if (existing.length) {
                this.embed = existing.first();
                _this.overlay.removeClass('anura-loading');
            } else {
                var tag = mime.indexOf('video') > -1 ? 'video' : (mime.indexOf('model') > -1 ? 'model-viewer' : 'embed');
                this.embed = $('<'+tag+'/>')
                    .attr('src', url).attr('type', mime).attr('controls', true).attr('draggable', false)
                    .attr('id', 'anura-lightbox-embed-' + this.assetId)
                    .attr('autoplay', url.indexOf('autoplay=true') > -1)
                    .one('load ready', function () {
                        _this.overlay.removeClass('anura-loading');
                    }).one('error', function () {
                        _this.overlay.removeClass('anura-loading');
                        _this.embed.attr('src', fallback_url).attr('type', fallback_mime);
                    }).appendTo(this.embed_wrapper);
                if (mime === 'image/jpeg' && !('objectFit' in document.documentElement.style)) { // IE 11 can't object-fit -.-
                    this.embed.attr('src','').css('background', 'url("'+url+'") no-repeat center center / contain');
                    _this.overlay.removeClass('anura-loading');
                } else if (tag === 'model-viewer') {
                    this.embed.addClass('noSwipe').attr('auto-rotate', true).attr('camera-controls', true);
                }
            }
            this.embed_wrapper.find('embed').removeClass('anura-active');
            this.embed.addClass('anura-active');
        },
        setBasketState: function() {
            if (this.basketButton) {
                if ($.inArray(this.assetId, this.options.basket.data('assets')) !== -1) {
                    this.basketButton.addClass('added').attr('title', this.strings['anura.removeFromBasket']);
                    if (this.options.sidebar.available) this.container.find('.anura-details-container tr.basket .anura-details-download-name') // TODO use events in details
                        .text(this.strings['anura.removeFromBasket']).attr('title', this.strings['anura.removeFromBasket']);
                } else {
                    this.basketButton.removeClass('added').attr('title', this.strings['anura.addToBasket']);
                    if (this.options.sidebar.available) this.container.find('.anura-details-container tr.basket .anura-details-download-name') // TODO use events in details
                        .text(this.strings['anura.addToBasket']).attr('title', this.strings['anura.addToBasket']);
                }
            }
        },
        updateCarouselPosition: function () {
            if (this.options.carousel && this.options.carousel.available) {
                this.carousel.find('.anura-lightbox-carousel-current').removeClass('anura-lightbox-carousel-current');
                var currentCarousel = this.carousel.find('#anura-lightbox-carousel-item-'+this.currentIndex).addClass('anura-lightbox-carousel-current');
                if (currentCarousel[0]) currentCarousel[0].scrollIntoView({block: 'center', inline: this.currentIndex < 1 ? 'start' : 'center', behavior: 'smooth'});
            }
        },
        prev: function() {
            if (!this.triggers || this.triggers.length < 2) return;
            this.currentIndex = this.getPrevIndex();
            // TODO instead of wrapping around we should do a pageCall
            this.showAsset($(this.triggers[this.currentIndex]));
        },
        getPrevIndex: function() {
            if (this.currentIndex == null) this.findCurrentIndex();
            if (this.currentIndex > 0) return this.currentIndex - 1;
            else return this.triggers.length - 1;
        },
        next: function() {
            if (!this.triggers || this.triggers.length < 2) return;
            this.currentIndex = this.getNextIndex();
            // TODO instead of wrapping around we should do a pageCall
            this.showAsset($(this.triggers[this.currentIndex]));
        },
        getNextIndex: function() {
            if (this.currentIndex == null) this.findCurrentIndex();
            if (this.currentIndex < this.triggers.length - 1) return this.currentIndex + 1;
            else return 0;
        },
        findCurrentIndex: function() {
            for (var i = 0; i < this.triggers.length; i++) {
                if ($(this.triggers[i]).data('asset-id') === this.assetId) {
                    this.currentIndex = i;
                    return;
                }
            }
        },
        addButton: function(target, btn_class, icon, text) {
            var a = $('<a />').addClass('anura-lightbox-button '+btn_class).attr('title', text || '').appendTo(target);
            if (icon) $(icon).appendTo(a.addClass('anura-lightbox-svg'));
            return a;
        }
    };
    $.fn[pluginName] = function ( options ) {
        return this.each(function (i, item) { // iterate matches
            var instance = $.data(item, "plugin_" + pluginName);
            if (!instance) { // if it has no instance yet, create it
                $.data(item, "plugin_" + pluginName, new Plugin( item, options ));
            } else { // otherwise merge new options with existing ones, empty and re-init
                instance.options = $.extend( {}, instance.options, options );
                instance.init();
            }
        });
    };
})( jQuery, window, document );

/*!
 * @fileOverview TouchSwipe - jQuery Plugin
 * @version 1.6.18
 *
 * @author Matt Bryson http://www.github.com/mattbryson
 * @see https://github.com/mattbryson/TouchSwipe-Jquery-Plugin
 * @see http://labs.rampinteractive.co.uk/touchSwipe
 * @license
 * Copyright (c) 2010-2015 Matt Bryson
 * Dual licensed under the MIT or GPL Version 2 licenses.
 *
 */
!function(factory){"function"==typeof define&&define.amd&&define.amd.jQuery?define(["jquery"],factory):factory("undefined"!=typeof module&&module.exports?require("jquery"):jQuery)}(function($){"use strict";function init(options){return!options||void 0!==options.allowPageScroll||void 0===options.swipe&&void 0===options.swipeStatus||(options.allowPageScroll=NONE),void 0!==options.click&&void 0===options.tap&&(options.tap=options.click),options||(options={}),options=$.extend({},$.fn.swipe.defaults,options),this.each(function(){var $this=$(this),plugin=$this.data(PLUGIN_NS);plugin||(plugin=new TouchSwipe(this,options),$this.data(PLUGIN_NS,plugin))})}function TouchSwipe(element,options){function touchStart(jqEvent){if(!(getTouchInProgress()||$(jqEvent.target).closest(options.excludedElements,$element).length>0)){var event=jqEvent.originalEvent?jqEvent.originalEvent:jqEvent;if(!event.pointerType||"mouse"!=event.pointerType||0!=options.fallbackToMouseEvents){var ret,touches=event.touches,evt=touches?touches[0]:event;return phase=PHASE_START,touches?fingerCount=touches.length:options.preventDefaultEvents!==!1&&jqEvent.preventDefault(),distance=0,direction=null,currentDirection=null,pinchDirection=null,duration=0,startTouchesDistance=0,endTouchesDistance=0,pinchZoom=1,pinchDistance=0,maximumsMap=createMaximumsData(),cancelMultiFingerRelease(),createFingerData(0,evt),!touches||fingerCount===options.fingers||options.fingers===ALL_FINGERS||hasPinches()?(startTime=getTimeStamp(),2==fingerCount&&(createFingerData(1,touches[1]),startTouchesDistance=endTouchesDistance=calculateTouchesDistance(fingerData[0].start,fingerData[1].start)),(options.swipeStatus||options.pinchStatus)&&(ret=triggerHandler(event,phase))):ret=!1,ret===!1?(phase=PHASE_CANCEL,triggerHandler(event,phase),ret):(options.hold&&(holdTimeout=setTimeout($.proxy(function(){$element.trigger("hold",[event.target]),options.hold&&(ret=options.hold.call($element,event,event.target))},this),options.longTapThreshold)),setTouchInProgress(!0),null)}}}function touchMove(jqEvent){var event=jqEvent.originalEvent?jqEvent.originalEvent:jqEvent;if(phase!==PHASE_END&&phase!==PHASE_CANCEL&&!inMultiFingerRelease()){var ret,touches=event.touches,evt=touches?touches[0]:event,currentFinger=updateFingerData(evt);if(endTime=getTimeStamp(),touches&&(fingerCount=touches.length),options.hold&&clearTimeout(holdTimeout),phase=PHASE_MOVE,2==fingerCount&&(0==startTouchesDistance?(createFingerData(1,touches[1]),startTouchesDistance=endTouchesDistance=calculateTouchesDistance(fingerData[0].start,fingerData[1].start)):(updateFingerData(touches[1]),endTouchesDistance=calculateTouchesDistance(fingerData[0].end,fingerData[1].end),pinchDirection=calculatePinchDirection(fingerData[0].end,fingerData[1].end)),pinchZoom=calculatePinchZoom(startTouchesDistance,endTouchesDistance),pinchDistance=Math.abs(startTouchesDistance-endTouchesDistance)),fingerCount===options.fingers||options.fingers===ALL_FINGERS||!touches||hasPinches()){if(direction=calculateDirection(currentFinger.start,currentFinger.end),currentDirection=calculateDirection(currentFinger.last,currentFinger.end),validateDefaultEvent(jqEvent,currentDirection),distance=calculateDistance(currentFinger.start,currentFinger.end),duration=calculateDuration(),setMaxDistance(direction,distance),ret=triggerHandler(event,phase),!options.triggerOnTouchEnd||options.triggerOnTouchLeave){var inBounds=!0;if(options.triggerOnTouchLeave){var bounds=getbounds(this);inBounds=isInBounds(currentFinger.end,bounds)}!options.triggerOnTouchEnd&&inBounds?phase=getNextPhase(PHASE_MOVE):options.triggerOnTouchLeave&&!inBounds&&(phase=getNextPhase(PHASE_END)),phase!=PHASE_CANCEL&&phase!=PHASE_END||triggerHandler(event,phase)}}else phase=PHASE_CANCEL,triggerHandler(event,phase);ret===!1&&(phase=PHASE_CANCEL,triggerHandler(event,phase))}}function touchEnd(jqEvent){var event=jqEvent.originalEvent?jqEvent.originalEvent:jqEvent,touches=event.touches;if(touches){if(touches.length&&!inMultiFingerRelease())return startMultiFingerRelease(event),!0;if(touches.length&&inMultiFingerRelease())return!0}return inMultiFingerRelease()&&(fingerCount=fingerCountAtRelease),endTime=getTimeStamp(),duration=calculateDuration(),didSwipeBackToCancel()||!validateSwipeDistance()?(phase=PHASE_CANCEL,triggerHandler(event,phase)):options.triggerOnTouchEnd||options.triggerOnTouchEnd===!1&&phase===PHASE_MOVE?(options.preventDefaultEvents!==!1&&jqEvent.preventDefault(),phase=PHASE_END,triggerHandler(event,phase)):!options.triggerOnTouchEnd&&hasTap()?(phase=PHASE_END,triggerHandlerForGesture(event,phase,TAP)):phase===PHASE_MOVE&&(phase=PHASE_CANCEL,triggerHandler(event,phase)),setTouchInProgress(!1),null}function touchCancel(){fingerCount=0,endTime=0,startTime=0,startTouchesDistance=0,endTouchesDistance=0,pinchZoom=1,cancelMultiFingerRelease(),setTouchInProgress(!1)}function touchLeave(jqEvent){var event=jqEvent.originalEvent?jqEvent.originalEvent:jqEvent;options.triggerOnTouchLeave&&(phase=getNextPhase(PHASE_END),triggerHandler(event,phase))}function removeListeners(){$element.unbind(START_EV,touchStart),$element.unbind(CANCEL_EV,touchCancel),$element.unbind(MOVE_EV,touchMove),$element.unbind(END_EV,touchEnd),LEAVE_EV&&$element.unbind(LEAVE_EV,touchLeave),setTouchInProgress(!1)}function getNextPhase(currentPhase){var nextPhase=currentPhase,validTime=validateSwipeTime(),validDistance=validateSwipeDistance(),didCancel=didSwipeBackToCancel();return!validTime||didCancel?nextPhase=PHASE_CANCEL:!validDistance||currentPhase!=PHASE_MOVE||options.triggerOnTouchEnd&&!options.triggerOnTouchLeave?!validDistance&&currentPhase==PHASE_END&&options.triggerOnTouchLeave&&(nextPhase=PHASE_CANCEL):nextPhase=PHASE_END,nextPhase}function triggerHandler(event,phase){var ret,touches=event.touches;return(didSwipe()||hasSwipes())&&(ret=triggerHandlerForGesture(event,phase,SWIPE)),(didPinch()||hasPinches())&&ret!==!1&&(ret=triggerHandlerForGesture(event,phase,PINCH)),didDoubleTap()&&ret!==!1?ret=triggerHandlerForGesture(event,phase,DOUBLE_TAP):didLongTap()&&ret!==!1?ret=triggerHandlerForGesture(event,phase,LONG_TAP):didTap()&&ret!==!1&&(ret=triggerHandlerForGesture(event,phase,TAP)),phase===PHASE_CANCEL&&touchCancel(event),phase===PHASE_END&&(touches?touches.length||touchCancel(event):touchCancel(event)),ret}function triggerHandlerForGesture(event,phase,gesture){var ret;if(gesture==SWIPE){if($element.trigger("swipeStatus",[phase,direction||null,distance||0,duration||0,fingerCount,fingerData,currentDirection]),options.swipeStatus&&(ret=options.swipeStatus.call($element,event,phase,direction||null,distance||0,duration||0,fingerCount,fingerData,currentDirection),ret===!1))return!1;if(phase==PHASE_END&&validateSwipe()){if(clearTimeout(singleTapTimeout),clearTimeout(holdTimeout),$element.trigger("swipe",[direction,distance,duration,fingerCount,fingerData,currentDirection]),options.swipe&&(ret=options.swipe.call($element,event,direction,distance,duration,fingerCount,fingerData,currentDirection),ret===!1))return!1;switch(direction){case LEFT:$element.trigger("swipeLeft",[direction,distance,duration,fingerCount,fingerData,currentDirection]),options.swipeLeft&&(ret=options.swipeLeft.call($element,event,direction,distance,duration,fingerCount,fingerData,currentDirection));break;case RIGHT:$element.trigger("swipeRight",[direction,distance,duration,fingerCount,fingerData,currentDirection]),options.swipeRight&&(ret=options.swipeRight.call($element,event,direction,distance,duration,fingerCount,fingerData,currentDirection));break;case UP:$element.trigger("swipeUp",[direction,distance,duration,fingerCount,fingerData,currentDirection]),options.swipeUp&&(ret=options.swipeUp.call($element,event,direction,distance,duration,fingerCount,fingerData,currentDirection));break;case DOWN:$element.trigger("swipeDown",[direction,distance,duration,fingerCount,fingerData,currentDirection]),options.swipeDown&&(ret=options.swipeDown.call($element,event,direction,distance,duration,fingerCount,fingerData,currentDirection))}}}if(gesture==PINCH){if($element.trigger("pinchStatus",[phase,pinchDirection||null,pinchDistance||0,duration||0,fingerCount,pinchZoom,fingerData]),options.pinchStatus&&(ret=options.pinchStatus.call($element,event,phase,pinchDirection||null,pinchDistance||0,duration||0,fingerCount,pinchZoom,fingerData),ret===!1))return!1;if(phase==PHASE_END&&validatePinch())switch(pinchDirection){case IN:$element.trigger("pinchIn",[pinchDirection||null,pinchDistance||0,duration||0,fingerCount,pinchZoom,fingerData]),options.pinchIn&&(ret=options.pinchIn.call($element,event,pinchDirection||null,pinchDistance||0,duration||0,fingerCount,pinchZoom,fingerData));break;case OUT:$element.trigger("pinchOut",[pinchDirection||null,pinchDistance||0,duration||0,fingerCount,pinchZoom,fingerData]),options.pinchOut&&(ret=options.pinchOut.call($element,event,pinchDirection||null,pinchDistance||0,duration||0,fingerCount,pinchZoom,fingerData))}}return gesture==TAP?phase!==PHASE_CANCEL&&phase!==PHASE_END||(clearTimeout(singleTapTimeout),clearTimeout(holdTimeout),hasDoubleTap()&&!inDoubleTap()?(doubleTapStartTime=getTimeStamp(),singleTapTimeout=setTimeout($.proxy(function(){doubleTapStartTime=null,$element.trigger("tap",[event.target]),options.tap&&(ret=options.tap.call($element,event,event.target))},this),options.doubleTapThreshold)):(doubleTapStartTime=null,$element.trigger("tap",[event.target]),options.tap&&(ret=options.tap.call($element,event,event.target)))):gesture==DOUBLE_TAP?phase!==PHASE_CANCEL&&phase!==PHASE_END||(clearTimeout(singleTapTimeout),clearTimeout(holdTimeout),doubleTapStartTime=null,$element.trigger("doubletap",[event.target]),options.doubleTap&&(ret=options.doubleTap.call($element,event,event.target))):gesture==LONG_TAP&&(phase!==PHASE_CANCEL&&phase!==PHASE_END||(clearTimeout(singleTapTimeout),doubleTapStartTime=null,$element.trigger("longtap",[event.target]),options.longTap&&(ret=options.longTap.call($element,event,event.target)))),ret}function validateSwipeDistance(){var valid=!0;return null!==options.threshold&&(valid=distance>=options.threshold),valid}function didSwipeBackToCancel(){var cancelled=!1;return null!==options.cancelThreshold&&null!==direction&&(cancelled=getMaxDistance(direction)-distance>=options.cancelThreshold),cancelled}function validatePinchDistance(){return null===options.pinchThreshold||pinchDistance>=options.pinchThreshold}function validateSwipeTime(){var result;return result=!options.maxTimeThreshold||!(duration>=options.maxTimeThreshold)}function validateDefaultEvent(jqEvent,direction){if(options.preventDefaultEvents!==!1)if(options.allowPageScroll===NONE)jqEvent.preventDefault();else{var auto=options.allowPageScroll===AUTO;switch(direction){case LEFT:(options.swipeLeft&&auto||!auto&&options.allowPageScroll!=HORIZONTAL)&&jqEvent.preventDefault();break;case RIGHT:(options.swipeRight&&auto||!auto&&options.allowPageScroll!=HORIZONTAL)&&jqEvent.preventDefault();break;case UP:(options.swipeUp&&auto||!auto&&options.allowPageScroll!=VERTICAL)&&jqEvent.preventDefault();break;case DOWN:(options.swipeDown&&auto||!auto&&options.allowPageScroll!=VERTICAL)&&jqEvent.preventDefault();break;case NONE:}}}function validatePinch(){var hasCorrectFingerCount=validateFingers(),hasEndPoint=validateEndPoint(),hasCorrectDistance=validatePinchDistance();return hasCorrectFingerCount&&hasEndPoint&&hasCorrectDistance}function hasPinches(){return!!(options.pinchStatus||options.pinchIn||options.pinchOut)}function didPinch(){return!(!validatePinch()||!hasPinches())}function validateSwipe(){var hasValidTime=validateSwipeTime(),hasValidDistance=validateSwipeDistance(),hasCorrectFingerCount=validateFingers(),hasEndPoint=validateEndPoint(),didCancel=didSwipeBackToCancel(),valid=!didCancel&&hasEndPoint&&hasCorrectFingerCount&&hasValidDistance&&hasValidTime;return valid}function hasSwipes(){return!!(options.swipe||options.swipeStatus||options.swipeLeft||options.swipeRight||options.swipeUp||options.swipeDown)}function didSwipe(){return!(!validateSwipe()||!hasSwipes())}function validateFingers(){return fingerCount===options.fingers||options.fingers===ALL_FINGERS||!SUPPORTS_TOUCH}function validateEndPoint(){return 0!==fingerData[0].end.x}function hasTap(){return!!options.tap}function hasDoubleTap(){return!!options.doubleTap}function hasLongTap(){return!!options.longTap}function validateDoubleTap(){if(null==doubleTapStartTime)return!1;var now=getTimeStamp();return hasDoubleTap()&&now-doubleTapStartTime<=options.doubleTapThreshold}function inDoubleTap(){return validateDoubleTap()}function validateTap(){return(1===fingerCount||!SUPPORTS_TOUCH)&&(isNaN(distance)||distance<options.threshold)}function validateLongTap(){return duration>options.longTapThreshold&&distance<DOUBLE_TAP_THRESHOLD}function didTap(){return!(!validateTap()||!hasTap())}function didDoubleTap(){return!(!validateDoubleTap()||!hasDoubleTap())}function didLongTap(){return!(!validateLongTap()||!hasLongTap())}function startMultiFingerRelease(event){previousTouchEndTime=getTimeStamp(),fingerCountAtRelease=event.touches.length+1}function cancelMultiFingerRelease(){previousTouchEndTime=0,fingerCountAtRelease=0}function inMultiFingerRelease(){var withinThreshold=!1;if(previousTouchEndTime){var diff=getTimeStamp()-previousTouchEndTime;diff<=options.fingerReleaseThreshold&&(withinThreshold=!0)}return withinThreshold}function getTouchInProgress(){return!($element.data(PLUGIN_NS+"_intouch")!==!0)}function setTouchInProgress(val){$element&&(val===!0?($element.bind(MOVE_EV,touchMove),$element.bind(END_EV,touchEnd),LEAVE_EV&&$element.bind(LEAVE_EV,touchLeave)):($element.unbind(MOVE_EV,touchMove,!1),$element.unbind(END_EV,touchEnd,!1),LEAVE_EV&&$element.unbind(LEAVE_EV,touchLeave,!1)),$element.data(PLUGIN_NS+"_intouch",val===!0))}function createFingerData(id,evt){var f={start:{x:0,y:0},last:{x:0,y:0},end:{x:0,y:0}};return f.start.x=f.last.x=f.end.x=evt.pageX||evt.clientX,f.start.y=f.last.y=f.end.y=evt.pageY||evt.clientY,fingerData[id]=f,f}function updateFingerData(evt){var id=void 0!==evt.identifier?evt.identifier:0,f=getFingerData(id);return null===f&&(f=createFingerData(id,evt)),f.last.x=f.end.x,f.last.y=f.end.y,f.end.x=evt.pageX||evt.clientX,f.end.y=evt.pageY||evt.clientY,f}function getFingerData(id){return fingerData[id]||null}function setMaxDistance(direction,distance){direction!=NONE&&(distance=Math.max(distance,getMaxDistance(direction)),maximumsMap[direction].distance=distance)}function getMaxDistance(direction){if(maximumsMap[direction])return maximumsMap[direction].distance}function createMaximumsData(){var maxData={};return maxData[LEFT]=createMaximumVO(LEFT),maxData[RIGHT]=createMaximumVO(RIGHT),maxData[UP]=createMaximumVO(UP),maxData[DOWN]=createMaximumVO(DOWN),maxData}function createMaximumVO(dir){return{direction:dir,distance:0}}function calculateDuration(){return endTime-startTime}function calculateTouchesDistance(startPoint,endPoint){var diffX=Math.abs(startPoint.x-endPoint.x),diffY=Math.abs(startPoint.y-endPoint.y);return Math.round(Math.sqrt(diffX*diffX+diffY*diffY))}function calculatePinchZoom(startDistance,endDistance){var percent=endDistance/startDistance*1;return percent.toFixed(2)}function calculatePinchDirection(){return pinchZoom<1?OUT:IN}function calculateDistance(startPoint,endPoint){return Math.round(Math.sqrt(Math.pow(endPoint.x-startPoint.x,2)+Math.pow(endPoint.y-startPoint.y,2)))}function calculateAngle(startPoint,endPoint){var x=startPoint.x-endPoint.x,y=endPoint.y-startPoint.y,r=Math.atan2(y,x),angle=Math.round(180*r/Math.PI);return angle<0&&(angle=360-Math.abs(angle)),angle}function calculateDirection(startPoint,endPoint){if(comparePoints(startPoint,endPoint))return NONE;var angle=calculateAngle(startPoint,endPoint);return angle<=45&&angle>=0?LEFT:angle<=360&&angle>=315?LEFT:angle>=135&&angle<=225?RIGHT:angle>45&&angle<135?DOWN:UP}function getTimeStamp(){var now=new Date;return now.getTime()}function getbounds(el){el=$(el);var offset=el.offset(),bounds={left:offset.left,right:offset.left+el.outerWidth(),top:offset.top,bottom:offset.top+el.outerHeight()};return bounds}function isInBounds(point,bounds){return point.x>bounds.left&&point.x<bounds.right&&point.y>bounds.top&&point.y<bounds.bottom}function comparePoints(pointA,pointB){return pointA.x==pointB.x&&pointA.y==pointB.y}var options=$.extend({},options),useTouchEvents=SUPPORTS_TOUCH||SUPPORTS_POINTER||!options.fallbackToMouseEvents,START_EV=useTouchEvents?SUPPORTS_POINTER?SUPPORTS_POINTER_IE10?"MSPointerDown":"pointerdown":"touchstart":"mousedown",MOVE_EV=useTouchEvents?SUPPORTS_POINTER?SUPPORTS_POINTER_IE10?"MSPointerMove":"pointermove":"touchmove":"mousemove",END_EV=useTouchEvents?SUPPORTS_POINTER?SUPPORTS_POINTER_IE10?"MSPointerUp":"pointerup":"touchend":"mouseup",LEAVE_EV=useTouchEvents?SUPPORTS_POINTER?"mouseleave":null:"mouseleave",CANCEL_EV=SUPPORTS_POINTER?SUPPORTS_POINTER_IE10?"MSPointerCancel":"pointercancel":"touchcancel",distance=0,direction=null,currentDirection=null,duration=0,startTouchesDistance=0,endTouchesDistance=0,pinchZoom=1,pinchDistance=0,pinchDirection=0,maximumsMap=null,$element=$(element),phase="start",fingerCount=0,fingerData={},startTime=0,endTime=0,previousTouchEndTime=0,fingerCountAtRelease=0,doubleTapStartTime=0,singleTapTimeout=null,holdTimeout=null;try{$element.bind(START_EV,touchStart),$element.bind(CANCEL_EV,touchCancel)}catch(e){$.error("events not supported "+START_EV+","+CANCEL_EV+" on jQuery.swipe")}this.enable=function(){return this.disable(),$element.bind(START_EV,touchStart),$element.bind(CANCEL_EV,touchCancel),$element},this.disable=function(){return removeListeners(),$element},this.destroy=function(){removeListeners(),$element.data(PLUGIN_NS,null),$element=null},this.option=function(property,value){if("object"==typeof property)options=$.extend(options,property);else if(void 0!==options[property]){if(void 0===value)return options[property];options[property]=value}else{if(!property)return options;$.error("Option "+property+" does not exist on jQuery.swipe.options")}return null}}var VERSION="1.6.18",LEFT="left",RIGHT="right",UP="up",DOWN="down",IN="in",OUT="out",NONE="none",AUTO="auto",SWIPE="swipe",PINCH="pinch",TAP="tap",DOUBLE_TAP="doubletap",LONG_TAP="longtap",HORIZONTAL="horizontal",VERTICAL="vertical",ALL_FINGERS="all",DOUBLE_TAP_THRESHOLD=10,PHASE_START="start",PHASE_MOVE="move",PHASE_END="end",PHASE_CANCEL="cancel",SUPPORTS_TOUCH="ontouchstart"in window,SUPPORTS_POINTER_IE10=window.navigator.msPointerEnabled&&!window.PointerEvent&&!SUPPORTS_TOUCH,SUPPORTS_POINTER=(window.PointerEvent||window.navigator.msPointerEnabled)&&!SUPPORTS_TOUCH,PLUGIN_NS="TouchSwipe",defaults={fingers:1,threshold:75,cancelThreshold:null,pinchThreshold:20,maxTimeThreshold:null,fingerReleaseThreshold:250,longTapThreshold:500,doubleTapThreshold:200,swipe:null,swipeLeft:null,swipeRight:null,swipeUp:null,swipeDown:null,swipeStatus:null,pinchIn:null,pinchOut:null,pinchStatus:null,click:null,tap:null,doubleTap:null,longTap:null,hold:null,triggerOnTouchEnd:!0,triggerOnTouchLeave:!1,allowPageScroll:"auto",fallbackToMouseEvents:!0,excludedElements:".noSwipe",preventDefaultEvents:!0};$.fn.swipe=function(method){var $this=$(this),plugin=$this.data(PLUGIN_NS);if(plugin&&"string"==typeof method){if(plugin[method])return plugin[method].apply(plugin,Array.prototype.slice.call(arguments,1));$.error("Method "+method+" does not exist on jQuery.swipe")}else if(plugin&&"object"==typeof method)plugin.option.apply(plugin,arguments);else if(!(plugin||"object"!=typeof method&&method))return init.apply(this,arguments);return $this},$.fn.swipe.version=VERSION,$.fn.swipe.defaults=defaults,$.fn.swipe.phases={PHASE_START:PHASE_START,PHASE_MOVE:PHASE_MOVE,PHASE_END:PHASE_END,PHASE_CANCEL:PHASE_CANCEL},$.fn.swipe.directions={LEFT:LEFT,RIGHT:RIGHT,UP:UP,DOWN:DOWN,IN:IN,OUT:OUT},$.fn.swipe.pageScroll={NONE:NONE,HORIZONTAL:HORIZONTAL,VERTICAL:VERTICAL,AUTO:AUTO},$.fn.swipe.fingers={ONE:1,TWO:2,THREE:3,FOUR:4,FIVE:5,ALL:ALL_FINGERS}});

